Class: Google::Apis::GkehubV1::ClusterUpgradeGkeUpgradeFeatureCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

GKEUpgradeFeatureCondition describes the condition of the feature for GKE clusters at a certain point of time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeGkeUpgradeFeatureCondition

Returns a new instance of ClusterUpgradeGkeUpgradeFeatureCondition.



480
481
482
# File 'lib/google/apis/gkehub_v1/classes.rb', line 480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

Reason why the feature is in this status. Corresponds to the JSON property reason

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/gkehub_v1/classes.rb', line 463

def reason
  @reason
end

#statusString

Status of the condition, one of True, False, Unknown. Corresponds to the JSON property status

Returns:

  • (String)


468
469
470
# File 'lib/google/apis/gkehub_v1/classes.rb', line 468

def status
  @status
end

#typeString

Type of the condition, for example, "ready". Corresponds to the JSON property type

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/gkehub_v1/classes.rb', line 473

def type
  @type
end

#update_timeString

Last timestamp the condition was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


478
479
480
# File 'lib/google/apis/gkehub_v1/classes.rb', line 478

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



485
486
487
488
489
490
# File 'lib/google/apis/gkehub_v1/classes.rb', line 485

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end