Class: Google::Apis::GkehubV1::CommonFleetDefaultMemberConfigSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

CommonFleetDefaultMemberConfigSpec contains default configuration information for memberships of a fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonFleetDefaultMemberConfigSpec

Returns a new instance of CommonFleetDefaultMemberConfigSpec.



917
918
919
# File 'lib/google/apis/gkehub_v1/classes.rb', line 917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configmanagementGoogle::Apis::GkehubV1::ConfigManagementMembershipSpec

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR. Corresponds to the JSON property configmanagement



899
900
901
# File 'lib/google/apis/gkehub_v1/classes.rb', line 899

def configmanagement
  @configmanagement
end

#identityserviceGoogle::Apis::GkehubV1::IdentityServiceMembershipSpec

Anthos Identity Service: Configuration for a single Membership. Corresponds to the JSON property identityservice



904
905
906
# File 'lib/google/apis/gkehub_v1/classes.rb', line 904

def identityservice
  @identityservice
end

#meshGoogle::Apis::GkehubV1::ServiceMeshMembershipSpec

Service Mesh: Spec for a single Membership for the servicemesh feature Corresponds to the JSON property mesh



909
910
911
# File 'lib/google/apis/gkehub_v1/classes.rb', line 909

def mesh
  @mesh
end

#policycontrollerGoogle::Apis::GkehubV1::PolicyControllerMembershipSpec

Policy Controller: Configuration for a single cluster. Intended to parallel the PolicyController CR. Corresponds to the JSON property policycontroller



915
916
917
# File 'lib/google/apis/gkehub_v1/classes.rb', line 915

def policycontroller
  @policycontroller
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



922
923
924
925
926
927
# File 'lib/google/apis/gkehub_v1/classes.rb', line 922

def update!(**args)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @mesh = args[:mesh] if args.key?(:mesh)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
end