Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

State information for ConfigSync

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncState

Returns a new instance of ConfigManagementConfigSyncState.



1195
1196
1197
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_level_stop_syncing_stateString

Output only. Whether syncing resources to the cluster is stopped at the cluster level. Corresponds to the JSON property clusterLevelStopSyncingState

Returns:

  • (String)


1152
1153
1154
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1152

def cluster_level_stop_syncing_state
  @cluster_level_stop_syncing_state
end

#cr_countFixnum

Output only. The number of RootSync and RepoSync CRs in the cluster. Corresponds to the JSON property crCount

Returns:

  • (Fixnum)


1157
1158
1159
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1157

def cr_count
  @cr_count
end

#deployment_stateGoogle::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState

The state of ConfigSync's deployment on a cluster Corresponds to the JSON property deploymentState



1162
1163
1164
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1162

def deployment_state
  @deployment_state
end

#errorsArray<Google::Apis::GkehubV1::ConfigManagementConfigSyncError>

Output only. Errors pertaining to the installation of Config Sync. Corresponds to the JSON property errors



1167
1168
1169
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1167

def errors
  @errors
end

#reposync_crdString

Output only. The state of the Reposync CRD Corresponds to the JSON property reposyncCrd

Returns:

  • (String)


1172
1173
1174
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1172

def reposync_crd
  @reposync_crd
end

#rootsync_crdString

Output only. The state of the RootSync CRD Corresponds to the JSON property rootsyncCrd

Returns:

  • (String)


1177
1178
1179
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1177

def rootsync_crd
  @rootsync_crd
end

#stateString

Output only. The state of CS This field summarizes the other fields in this message. Corresponds to the JSON property state

Returns:

  • (String)


1183
1184
1185
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1183

def state
  @state
end

#sync_stateGoogle::Apis::GkehubV1::ConfigManagementSyncState

State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property syncState



1188
1189
1190
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1188

def sync_state
  @sync_state
end

#versionGoogle::Apis::GkehubV1::ConfigManagementConfigSyncVersion

Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property version



1193
1194
1195
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1193

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1200

def update!(**args)
  @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state)
  @cr_count = args[:cr_count] if args.key?(:cr_count)
  @deployment_state = args[:deployment_state] if args.key?(:deployment_state)
  @errors = args[:errors] if args.key?(:errors)
  @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd)
  @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd)
  @state = args[:state] if args.key?(:state)
  @sync_state = args[:sync_state] if args.key?(:sync_state)
  @version = args[:version] if args.key?(:version)
end