Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Specific versioning information pertaining to ConfigSync's Pods

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncVersion

Returns a new instance of ConfigManagementConfigSyncVersion.



1256
1257
1258
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Version of the deployed admission-webhook pod Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1214
1215
1216
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1214

def admission_webhook
  @admission_webhook
end

#git_syncString

Version of the deployed git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1219
1220
1221
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1219

def git_sync
  @git_sync
end

#importerString

Version of the deployed importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1224
1225
1226
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1224

def importer
  @importer
end

#monitorString

Version of the deployed monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1229
1230
1231
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1229

def monitor
  @monitor
end

#otel_collectorString

Version of the deployed otel-collector pod Corresponds to the JSON property otelCollector

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1234

def otel_collector
  @otel_collector
end

#reconciler_managerString

Version of the deployed reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1239
1240
1241
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1239

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Version of the deployed resource-group-controller-manager pod Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1244
1245
1246
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1244

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Version of the deployed reconciler container in root-reconciler pod Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1249
1250
1251
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1249

def root_reconciler
  @root_reconciler
end

#syncerString

Version of the deployed syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1254
1255
1256
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1254

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1261

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end