Class: Google::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration for Hierarchy Controller

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementHierarchyControllerConfig

Returns a new instance of ConfigManagementHierarchyControllerConfig.



1453
1454
1455
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_hierarchical_resource_quotaBoolean Also known as: enable_hierarchical_resource_quota?

Whether hierarchical resource quota is enabled in this cluster. Corresponds to the JSON property enableHierarchicalResourceQuota

Returns:

  • (Boolean)


1438
1439
1440
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1438

def enable_hierarchical_resource_quota
  @enable_hierarchical_resource_quota
end

#enable_pod_tree_labelsBoolean Also known as: enable_pod_tree_labels?

Whether pod tree labels are enabled in this cluster. Corresponds to the JSON property enablePodTreeLabels

Returns:

  • (Boolean)


1444
1445
1446
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1444

def enable_pod_tree_labels
  @enable_pod_tree_labels
end

#enabledBoolean Also known as: enabled?

Whether Hierarchy Controller is enabled in this cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1450
1451
1452
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1450

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1458
1459
1460
1461
1462
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1458

def update!(**args)
  @enable_hierarchical_resource_quota = args[:enable_hierarchical_resource_quota] if args.key?(:enable_hierarchical_resource_quota)
  @enable_pod_tree_labels = args[:enable_pod_tree_labels] if args.key?(:enable_pod_tree_labels)
  @enabled = args[:enabled] if args.key?(:enabled)
end