Class: Google::Apis::GkehubV1::ConfigManagementMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ConfigManagementMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Optional.
-
#config_sync ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSync
Configuration for Config Sync Corresponds to the JSON property
configSync. -
#hierarchy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller Corresponds to the JSON property
hierarchyController. -
#management ⇒ String
Optional.
-
#policy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementPolicyController
Configuration for Policy Controller Corresponds to the JSON property
policyController. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementMembershipSpec
constructor
A new instance of ConfigManagementMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementMembershipSpec
Returns a new instance of ConfigManagementMembershipSpec.
1703 1704 1705 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Optional. User-specified cluster name used by the Config Sync cluster-name-
selector annotation or ClusterSelector object, for applying configs to only a
subset of clusters. Read more about the cluster-name-selector annotation and
ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/
config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this
field if a name different from the cluster's fleet membership name is used by
the Config Sync cluster-name-selector annotation or ClusterSelector.
Corresponds to the JSON property cluster
1669 1670 1671 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1669 def cluster @cluster end |
#config_sync ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSync
Configuration for Config Sync
Corresponds to the JSON property configSync
1674 1675 1676 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1674 def config_sync @config_sync end |
#hierarchy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller
Corresponds to the JSON property hierarchyController
1679 1680 1681 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1679 def hierarchy_controller @hierarchy_controller end |
#management ⇒ String
Optional. Deprecated: Automatic Feature management is in Preview and is
unavailable in version 1.21.0 and later, after which Config Sync only supports
manual upgrades. If set to manual upgrades, clear this field instead, which is
behaviorally equivalent but helps prevent compatibility issues with newer
fields.
Corresponds to the JSON property management
1688 1689 1690 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1688 def management @management end |
#policy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementPolicyController
Configuration for Policy Controller
Corresponds to the JSON property policyController
1693 1694 1695 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1693 def policy_controller @policy_controller end |
#version ⇒ String
Optional. Version of Config Sync to install. Defaults to the latest supported
Config Sync version if the config_sync field is enabled. See supported
versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get-
support-config-sync#version_support_policy.
Corresponds to the JSON property version
1701 1702 1703 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1701 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1708 1709 1710 1711 1712 1713 1714 1715 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1708 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @config_sync = args[:config_sync] if args.key?(:config_sync) @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller) @management = args[:management] if args.key?(:management) @policy_controller = args[:policy_controller] if args.key?(:policy_controller) @version = args[:version] if args.key?(:version) end |