Class: Google::Apis::GkehubV1::ConfigManagementPolicyControllerVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

The build version of Gatekeeper Policy Controller is using.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementPolicyControllerVersion

Returns a new instance of ConfigManagementPolicyControllerVersion.



1918
1919
1920
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#versionString

The gatekeeper image tag that is composed of ACM version, git tag, build number. Corresponds to the JSON property version

Returns:

  • (String)


1916
1917
1918
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1916

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1923
1924
1925
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1923

def update!(**args)
  @version = args[:version] if args.key?(:version)
end