Class: Google::Apis::GkehubV1::ConnectAgentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

ConnectAgentResource represents a Kubernetes resource manifest for Connect Agent deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectAgentResource

Returns a new instance of ConnectAgentResource.



2129
2130
2131
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manifestString

YAML manifest of the resource. Corresponds to the JSON property manifest

Returns:

  • (String)


2121
2122
2123
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2121

def manifest
  @manifest
end

#typeGoogle::Apis::GkehubV1::TypeMeta

TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest. Corresponds to the JSON property type



2127
2128
2129
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2127

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2134
2135
2136
2137
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2134

def update!(**args)
  @manifest = args[:manifest] if args.key?(:manifest)
  @type = args[:type] if args.key?(:type)
end