Class: Google::Apis::GkehubV1::DefaultClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

DefaultClusterConfig describes the default cluster configurations to be applied to all clusters born-in-fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DefaultClusterConfig

Returns a new instance of DefaultClusterConfig.



2193
2194
2195
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_authorization_configGoogle::Apis::GkehubV1::BinaryAuthorizationConfig

BinaryAuthorizationConfig defines the fleet level configuration of binary authorization feature. Corresponds to the JSON property binaryAuthorizationConfig



2177
2178
2179
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2177

def binary_authorization_config
  @binary_authorization_config
end

#compliance_posture_configGoogle::Apis::GkehubV1::CompliancePostureConfig

Deprecated: Compliance Posture is no longer supported. For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture- management-deprecation. CompliancePostureConfig defines the settings needed to enable/disable features for the Compliance Posture. Corresponds to the JSON property compliancePostureConfig



2185
2186
2187
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2185

def compliance_posture_config
  @compliance_posture_config
end

#security_posture_configGoogle::Apis::GkehubV1::SecurityPostureConfig

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API. Corresponds to the JSON property securityPostureConfig



2191
2192
2193
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2191

def security_posture_config
  @security_posture_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2198
2199
2200
2201
2202
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2198

def update!(**args)
  @binary_authorization_config = args[:binary_authorization_config] if args.key?(:binary_authorization_config)
  @compliance_posture_config = args[:compliance_posture_config] if args.key?(:compliance_posture_config)
  @security_posture_config = args[:security_posture_config] if args.key?(:security_posture_config)
end