Class: Google::Apis::GkehubV1::IdentityServiceAzureAdConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration for the AzureAD Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceAzureAdConfig

Returns a new instance of IdentityServiceAzureAdConfig.



3003
3004
3005
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

ID for the registered client application that makes authentication requests to the Azure AD identity provider. Corresponds to the JSON property clientId

Returns:

  • (String)


2968
2969
2970
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2968

def client_id
  @client_id
end

#client_secretString

Input only. Unencrypted AzureAD client secret will be passed to the GKE Hub CLH. Corresponds to the JSON property clientSecret

Returns:

  • (String)


2974
2975
2976
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2974

def client_secret
  @client_secret
end

#encrypted_client_secretString

Output only. Encrypted AzureAD client secret. Corresponds to the JSON property encryptedClientSecret NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2980
2981
2982
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2980

def encrypted_client_secret
  @encrypted_client_secret
end

#group_formatString

Optional. Format of the AzureAD groups that the client wants for auth. Corresponds to the JSON property groupFormat

Returns:

  • (String)


2985
2986
2987
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2985

def group_format
  @group_format
end

#kubectl_redirect_uriString

The redirect URL that kubectl uses for authorization. Corresponds to the JSON property kubectlRedirectUri

Returns:

  • (String)


2990
2991
2992
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2990

def kubectl_redirect_uri
  @kubectl_redirect_uri
end

#tenantString

Kind of Azure AD account to be authenticated. Supported values are or for accounts belonging to a specific tenant. Corresponds to the JSON property tenant

Returns:

  • (String)


2996
2997
2998
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2996

def tenant
  @tenant
end

#user_claimString

Optional. Claim in the AzureAD ID Token that holds the user details. Corresponds to the JSON property userClaim

Returns:

  • (String)


3001
3002
3003
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3001

def user_claim
  @user_claim
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3008
3009
3010
3011
3012
3013
3014
3015
3016
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3008

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret)
  @group_format = args[:group_format] if args.key?(:group_format)
  @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri)
  @tenant = args[:tenant] if args.key?(:tenant)
  @user_claim = args[:user_claim] if args.key?(:user_claim)
end