Class: Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration options for the AIS diagnostic interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceDiagnosticInterface

Returns a new instance of IdentityServiceDiagnosticInterface.



3041
3042
3043
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Determines whether to enable the diagnostic interface. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


3032
3033
3034
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3032

def enabled
  @enabled
end

#expiration_timeString

Determines the expiration time of the diagnostic interface enablement. When reached, requests to the interface would be automatically rejected. Corresponds to the JSON property expirationTime

Returns:

  • (String)


3039
3040
3041
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3039

def expiration_time
  @expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3046
3047
3048
3049
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3046

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
end