Class: Google::Apis::GkehubV1::IdentityServiceOidcConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration for OIDC Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceOidcConfig

Returns a new instance of IdentityServiceOidcConfig.



3328
3329
3330
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_authority_dataString

PEM-encoded CA for OIDC provider. Corresponds to the JSON property certificateAuthorityData

Returns:

  • (String)


3255
3256
3257
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3255

def certificate_authority_data
  @certificate_authority_data
end

#client_idString

ID for OIDC client application. Corresponds to the JSON property clientId

Returns:

  • (String)


3260
3261
3262
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3260

def client_id
  @client_id
end

#client_secretString

Input only. Unencrypted OIDC client secret will be passed to the GKE Hub CLH. Corresponds to the JSON property clientSecret

Returns:

  • (String)


3265
3266
3267
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3265

def client_secret
  @client_secret
end

#deploy_cloud_console_proxyBoolean Also known as: deploy_cloud_console_proxy?

Flag to denote if reverse proxy is used to connect to auth provider. This flag should be set to true when provider is not reachable by Google Cloud Console. Corresponds to the JSON property deployCloudConsoleProxy

Returns:

  • (Boolean)


3271
3272
3273
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3271

def deploy_cloud_console_proxy
  @deploy_cloud_console_proxy
end

#enable_access_tokenBoolean Also known as: enable_access_token?

Enable access token. Corresponds to the JSON property enableAccessToken

Returns:

  • (Boolean)


3277
3278
3279
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3277

def enable_access_token
  @enable_access_token
end

#encrypted_client_secretString

Output only. Encrypted OIDC Client secret Corresponds to the JSON property encryptedClientSecret NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3284
3285
3286
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3284

def encrypted_client_secret
  @encrypted_client_secret
end

#extra_paramsString

Comma-separated list of key-value pairs. Corresponds to the JSON property extraParams

Returns:

  • (String)


3289
3290
3291
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3289

def extra_params
  @extra_params
end

#group_prefixString

Prefix to prepend to group name. Corresponds to the JSON property groupPrefix

Returns:

  • (String)


3294
3295
3296
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3294

def group_prefix
  @group_prefix
end

#groups_claimString

Claim in OIDC ID token that holds group information. Corresponds to the JSON property groupsClaim

Returns:

  • (String)


3299
3300
3301
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3299

def groups_claim
  @groups_claim
end

#issuer_uriString

URI for the OIDC provider. This should point to the level below .well-known/ openid-configuration. Corresponds to the JSON property issuerUri

Returns:

  • (String)


3305
3306
3307
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3305

def issuer_uri
  @issuer_uri
end

#kubectl_redirect_uriString

Registered redirect uri to redirect users going through OAuth flow using kubectl plugin. Corresponds to the JSON property kubectlRedirectUri

Returns:

  • (String)


3311
3312
3313
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3311

def kubectl_redirect_uri
  @kubectl_redirect_uri
end

#scopesString

Comma-separated list of identifiers. Corresponds to the JSON property scopes

Returns:

  • (String)


3316
3317
3318
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3316

def scopes
  @scopes
end

#user_claimString

Claim in OIDC ID token that holds username. Corresponds to the JSON property userClaim

Returns:

  • (String)


3321
3322
3323
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3321

def user_claim
  @user_claim
end

#user_prefixString

Prefix to prepend to user name. Corresponds to the JSON property userPrefix

Returns:

  • (String)


3326
3327
3328
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3326

def user_prefix
  @user_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3333

def update!(**args)
  @certificate_authority_data = args[:certificate_authority_data] if args.key?(:certificate_authority_data)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @deploy_cloud_console_proxy = args[:deploy_cloud_console_proxy] if args.key?(:deploy_cloud_console_proxy)
  @enable_access_token = args[:enable_access_token] if args.key?(:enable_access_token)
  @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret)
  @extra_params = args[:extra_params] if args.key?(:extra_params)
  @group_prefix = args[:group_prefix] if args.key?(:group_prefix)
  @groups_claim = args[:groups_claim] if args.key?(:groups_claim)
  @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri)
  @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
  @user_claim = args[:user_claim] if args.key?(:user_claim)
  @user_prefix = args[:user_prefix] if args.key?(:user_prefix)
end