Class: Google::Apis::GkehubV1::KubernetesResource
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::KubernetesResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster.
Instance Attribute Summary collapse
-
#connect_resources ⇒ Array<Google::Apis::GkehubV1::ResourceManifest>
Output only.
-
#membership_cr_manifest ⇒ String
Input only.
-
#membership_resources ⇒ Array<Google::Apis::GkehubV1::ResourceManifest>
Output only.
-
#resource_options ⇒ Google::Apis::GkehubV1::ResourceOptions
ResourceOptions represent options for Kubernetes resource generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KubernetesResource
constructor
A new instance of KubernetesResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KubernetesResource
Returns a new instance of KubernetesResource.
3652 3653 3654 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connect_resources ⇒ Array<Google::Apis::GkehubV1::ResourceManifest>
Output only. The Kubernetes resources for installing the GKE Connect agent
This field is only populated in the Membership returned from a successful long-
running operation from CreateMembership or UpdateMembership. It is not
populated during normal GetMembership or ListMemberships requests. To get the
resource manifest after the initial registration, the caller should make a
UpdateMembership call with an empty field mask.
Corresponds to the JSON property connectResources
3624 3625 3626 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3624 def connect_resources @connect_resources end |
#membership_cr_manifest ⇒ String
Input only. The YAML representation of the Membership CR. This field is
ignored for GKE clusters where Hub can read the CR directly. Callers should
provide the CR that is currently present in the cluster during
CreateMembership or UpdateMembership, or leave this field empty if none exists.
The CR manifest is used to validate the cluster has not been registered with
another Membership.
Corresponds to the JSON property membershipCrManifest
3634 3635 3636 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3634 def membership_cr_manifest @membership_cr_manifest end |
#membership_resources ⇒ Array<Google::Apis::GkehubV1::ResourceManifest>
Output only. Additional Kubernetes resources that need to be applied to the
cluster after Membership creation, and after every update. This field is only
populated in the Membership returned from a successful long-running operation
from CreateMembership or UpdateMembership. It is not populated during normal
GetMembership or ListMemberships requests. To get the resource manifest after
the initial registration, the caller should make a UpdateMembership call with
an empty field mask.
Corresponds to the JSON property membershipResources
3645 3646 3647 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3645 def membership_resources @membership_resources end |
#resource_options ⇒ Google::Apis::GkehubV1::ResourceOptions
ResourceOptions represent options for Kubernetes resource generation.
Corresponds to the JSON property resourceOptions
3650 3651 3652 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3650 def @resource_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3657 3658 3659 3660 3661 3662 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3657 def update!(**args) @connect_resources = args[:connect_resources] if args.key?(:connect_resources) @membership_cr_manifest = args[:membership_cr_manifest] if args.key?(:membership_cr_manifest) @membership_resources = args[:membership_resources] if args.key?(:membership_resources) @resource_options = args[:resource_options] if args.key?(:resource_options) end |