Class: Google::Apis::GkehubV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::GkehubV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
3810 3811 3812 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
3795 3796 3797 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3795 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::GkehubV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
3800 3801 3802 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3800 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
3808 3809 3810 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3808 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3815 3816 3817 3818 3819 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3815 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |