Class: Google::Apis::GkehubV1::ListScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopesResponse

Returns a new instance of ListScopesResponse.



4064
4065
4066
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4057
4058
4059
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4057

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1::Scope>

The list of Scopes Corresponds to the JSON property scopes

Returns:



4062
4063
4064
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4062

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4069
4070
4071
4072
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4069

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end