Class: Google::Apis::GkehubV1::MembershipBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

MembershipBinding is a subresource of a Membership, representing what Fleet Scopes (or other, future Fleet resources) a Membership is bound to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipBinding

Returns a new instance of MembershipBinding.



4288
4289
4290
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the membership binding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4248
4249
4250
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4248

def create_time
  @create_time
end

#delete_timeString

Output only. When the membership binding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4253

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this MembershipBinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4258
4259
4260
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4258

def labels
  @labels
end

#nameString

The resource name for the membershipbinding itself projects/project/ locations/location/memberships/membership/bindings/membershipbinding` Corresponds to the JSON propertyname`

Returns:

  • (String)


4264
4265
4266
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4264

def name
  @name
end

#scopeString

A Scope resource name in the format projects/*/locations/*/scopes/*. Corresponds to the JSON property scope

Returns:

  • (String)


4269
4270
4271
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4269

def scope
  @scope
end

#stateGoogle::Apis::GkehubV1::MembershipBindingLifecycleState

MembershipBindingLifecycleState describes the state of a Binding resource. Corresponds to the JSON property state



4274
4275
4276
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4274

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all membershipbinding resources. If a membershipbinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4281

def uid
  @uid
end

#update_timeString

Output only. When the membership binding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4286
4287
4288
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4286

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4293

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @scope = args[:scope] if args.key?(:scope)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end