Class: Google::Apis::GkehubV1::MembershipFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

MembershipFeatureState contains Feature status information for a single Membership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipFeatureState

Returns a new instance of MembershipFeatureState.



4497
4498
4499
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV1::AppDevExperienceFeatureState

State for App Dev Exp Feature. Corresponds to the JSON property appdevexperience



4450
4451
4452
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4450

def appdevexperience
  @appdevexperience
end

#clusterupgradeGoogle::Apis::GkehubV1::ClusterUpgradeMembershipState

Per-membership state for this feature. Corresponds to the JSON property clusterupgrade



4455
4456
4457
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4455

def clusterupgrade
  @clusterupgrade
end

#configmanagementGoogle::Apis::GkehubV1::ConfigManagementMembershipState

Anthos Config Management: State for a single cluster. Corresponds to the JSON property configmanagement



4460
4461
4462
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4460

def configmanagement
  @configmanagement
end

#fleetobservabilityGoogle::Apis::GkehubV1::FleetObservabilityMembershipState

FleetObservability: Membership-specific Feature state for fleetobservability. Corresponds to the JSON property fleetobservability



4466
4467
4468
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4466

def fleetobservability
  @fleetobservability
end

#identityserviceGoogle::Apis::GkehubV1::IdentityServiceMembershipState

Anthos Identity Service: State for a single Membership. Corresponds to the JSON property identityservice



4471
4472
4473
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4471

def identityservice
  @identityservice
end

#policycontrollerGoogle::Apis::GkehubV1::PolicyControllerMembershipState

Policy Controller: State for a single cluster. Corresponds to the JSON property policycontroller



4476
4477
4478
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4476

def policycontroller
  @policycontroller
end

#servicemeshGoogle::Apis::GkehubV1::ServiceMeshMembershipState

Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller. Corresponds to the JSON property servicemesh



4482
4483
4484
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4482

def servicemesh
  @servicemesh
end

#stateGoogle::Apis::GkehubV1::FeatureState

FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context. Corresponds to the JSON property state



4489
4490
4491
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4489

def state
  @state
end

#workloadidentityGoogle::Apis::GkehubV1::WorkloadIdentityMembershipState

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature. Corresponds to the JSON property workloadidentity



4495
4496
4497
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4495

def workloadidentity
  @workloadidentity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4502
4503
4504
4505
4506
4507
4508
4509
4510
4511
4512
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4502

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
  @servicemesh = args[:servicemesh] if args.key?(:servicemesh)
  @state = args[:state] if args.key?(:state)
  @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity)
end