Class: Google::Apis::GkehubV1::Namespace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Namespace represents a namespace across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Namespace

Returns a new instance of Namespace.



4514
4515
4516
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the namespace was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4465
4466
4467
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4465

def create_time
  @create_time
end

#delete_timeString

Output only. When the namespace was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4470
4471
4472
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4470

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Namespace. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4475
4476
4477
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4475

def labels
  @labels
end

#nameString

The resource name for the namespace projects/project/locations/location/ namespaces/namespace` Corresponds to the JSON propertyname`

Returns:

  • (String)


4481
4482
4483
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4481

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Namespace-level cluster namespace labels. These labels are applied to the related namespace of the member clusters bound to the parent Scope. Scope-level labels (namespace_labels in the Fleet Scope resource) take precedence over Namespace-level labels if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


4490
4491
4492
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4490

def namespace_labels
  @namespace_labels
end

#scopeString

Required. Scope associated with the namespace Corresponds to the JSON property scope

Returns:

  • (String)


4495
4496
4497
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4495

def scope
  @scope
end

#stateGoogle::Apis::GkehubV1::NamespaceLifecycleState

NamespaceLifecycleState describes the state of a Namespace resource. Corresponds to the JSON property state



4500
4501
4502
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4500

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all namespace resources. If a namespace resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4507
4508
4509
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4507

def uid
  @uid
end

#update_timeString

Output only. When the namespace was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4512
4513
4514
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4512

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4519
4520
4521
4522
4523
4524
4525
4526
4527
4528
4529
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4519

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @scope = args[:scope] if args.key?(:scope)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end