Class: Google::Apis::GkehubV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



4874
4875
4876
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


4838
4839
4840
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4838

def api_version
  @api_version
end

#cancel_requestedBoolean Also known as: cancel_requested?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelRequested

Returns:

  • (Boolean)


4846
4847
4848
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4846

def cancel_requested
  @cancel_requested
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4852

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


4857
4858
4859
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4857

def end_time
  @end_time
end

#status_detailString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusDetail

Returns:

  • (String)


4862
4863
4864
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4862

def status_detail
  @status_detail
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


4867
4868
4869
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4867

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


4872
4873
4874
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4872

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4879

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end