Class: Google::Apis::GkehubV1::PolicyControllerBundleInstallSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

BundleInstallSpec is the specification configuration for a single managed bundle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerBundleInstallSpec

Returns a new instance of PolicyControllerBundleInstallSpec.



4860
4861
4862
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempted_namespacesArray<String>

The set of namespaces to be exempted from the bundle. Corresponds to the JSON property exemptedNamespaces

Returns:

  • (Array<String>)


4858
4859
4860
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4858

def exempted_namespaces
  @exempted_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4865
4866
4867
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4865

def update!(**args)
  @exempted_namespaces = args[:exempted_namespaces] if args.key?(:exempted_namespaces)
end