Class: Google::Apis::GkehubV1::PolicyControllerPolicyContentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

The state of the policy controller policy content

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerPolicyContentState

Returns a new instance of PolicyControllerPolicyContentState.



5338
5339
5340
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_statesHash<String,Google::Apis::GkehubV1::PolicyControllerOnClusterState>

The state of the any bundles included in the chosen version of the manifest Corresponds to the JSON property bundleStates



5326
5327
5328
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5326

def bundle_states
  @bundle_states
end

#referential_sync_config_stateGoogle::Apis::GkehubV1::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property referentialSyncConfigState



5331
5332
5333
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5331

def referential_sync_config_state
  @referential_sync_config_state
end

#template_library_stateGoogle::Apis::GkehubV1::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property templateLibraryState



5336
5337
5338
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5336

def template_library_state
  @template_library_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5343
5344
5345
5346
5347
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5343

def update!(**args)
  @bundle_states = args[:bundle_states] if args.key?(:bundle_states)
  @referential_sync_config_state = args[:referential_sync_config_state] if args.key?(:referential_sync_config_state)
  @template_library_state = args[:template_library_state] if args.key?(:template_library_state)
end