Class: Google::Apis::GkehubV1::PolicyControllerTemplateLibraryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

The config specifying which default library templates to install.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerTemplateLibraryConfig

Returns a new instance of PolicyControllerTemplateLibraryConfig.



5225
5226
5227
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#installationString

Configures the manner in which the template library is installed on the cluster. Corresponds to the JSON property installation

Returns:

  • (String)


5223
5224
5225
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5223

def installation
  @installation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5230
5231
5232
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5230

def update!(**args)
  @installation = args[:installation] if args.key?(:installation)
end