Class: Google::Apis::GkehubV1::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



5333
5334
5335
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5279
5280
5281
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5279

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5284
5285
5286
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5284

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


5289
5290
5291
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5289

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5294
5295
5296
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5294

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


5302
5303
5304
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5302

def name
  @name
end

#roleGoogle::Apis::GkehubV1::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



5307
5308
5309
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5307

def role
  @role
end

#stateGoogle::Apis::GkehubV1::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



5313
5314
5315
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5313

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5320
5321
5322
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5320

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5325
5326
5327
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5325

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5331

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5338
5339
5340
5341
5342
5343
5344
5345
5346
5347
5348
5349
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5338

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end