Class: Google::Apis::GkehubV1::RbacRoleBindingActuationFeatureSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

RBAC RoleBinding Actuation: The Hub-wide input for the RBACRoleBindingActuation feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBindingActuationFeatureSpec

Returns a new instance of RbacRoleBindingActuationFeatureSpec.



5408
5409
5410
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_custom_rolesArray<String>

The list of allowed custom roles (ClusterRoles). If a ClusterRole is not part of this list, it cannot be used in a Scope RBACRoleBinding. If a ClusterRole in this list is in use, it cannot be removed from the list. Corresponds to the JSON property allowedCustomRoles

Returns:

  • (Array<String>)


5406
5407
5408
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5406

def allowed_custom_roles
  @allowed_custom_roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5413
5414
5415
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5413

def update!(**args)
  @allowed_custom_roles = args[:allowed_custom_roles] if args.key?(:allowed_custom_roles)
end