Class: Google::Apis::GkehubV1::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

RolloutSequence defines the desired order of upgrades. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6040
6041
6042
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_configGoogle::Apis::GkehubV1::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property autoUpgradeConfig



5950
5951
5952
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5950

def auto_upgrade_config
  @auto_upgrade_config
end

#computed_release_channelString

Output only. The computed release channel used for the Rollout Sequence. Corresponds to the JSON property computedReleaseChannel

Returns:

  • (String)


5955
5956
5957
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5955

def computed_release_channel
  @computed_release_channel
end

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5960
5961
5962
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5960

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5965
5966
5967
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5965

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


5970
5971
5972
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5970

def display_name
  @display_name
end

#effective_auto_upgrade_configGoogle::Apis::GkehubV1::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property effectiveAutoUpgradeConfig



5975
5976
5977
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5975

def effective_auto_upgrade_config
  @effective_auto_upgrade_config
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


5980
5981
5982
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5980

def etag
  @etag
end

#ignored_clusters_selectorGoogle::Apis::GkehubV1::ClusterSelector

Selector for clusters. Corresponds to the JSON property ignoredClustersSelector



5985
5986
5987
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5985

def ignored_clusters_selector
  @ignored_clusters_selector
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5990
5991
5992
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5990

def labels
  @labels
end

#last_qualified_control_plane_versionString

Output only. The last qualified control plane version. Corresponds to the JSON property lastQualifiedControlPlaneVersion

Returns:

  • (String)


5995
5996
5997
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5995

def last_qualified_control_plane_version
  @last_qualified_control_plane_version
end

#last_qualified_node_versionString

Output only. The last qualified node version. Corresponds to the JSON property lastQualifiedNodeVersion

Returns:

  • (String)


6000
6001
6002
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6000

def last_qualified_node_version
  @last_qualified_node_version
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6006
6007
6008
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6006

def name
  @name
end

#operational_stateGoogle::Apis::GkehubV1::OperationalState

Operational state of the Rollout Sequence. Corresponds to the JSON property operationalState



6011
6012
6013
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6011

def operational_state
  @operational_state
end

#stagesArray<Google::Apis::GkehubV1::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages

Returns:



6016
6017
6018
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6016

def stages
  @stages
end

#target_control_plane_versionString

Output only. The target control plane version of the Rollout Sequence. Corresponds to the JSON property targetControlPlaneVersion

Returns:

  • (String)


6021
6022
6023
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6021

def target_control_plane_version
  @target_control_plane_version
end

#target_node_versionString

Output only. The target node version of the Rollout Sequence. Corresponds to the JSON property targetNodeVersion

Returns:

  • (String)


6026
6027
6028
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6026

def target_node_version
  @target_node_version
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6033
6034
6035
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6033

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6038
6039
6040
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6038

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6045

def update!(**args)
  @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config)
  @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config)
  @etag = args[:etag] if args.key?(:etag)
  @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector)
  @labels = args[:labels] if args.key?(:labels)
  @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version)
  @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version)
  @name = args[:name] if args.key?(:name)
  @operational_state = args[:operational_state] if args.key?(:operational_state)
  @stages = args[:stages] if args.key?(:stages)
  @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version)
  @target_node_version = args[:target_node_version] if args.key?(:target_node_version)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end