Class: Google::Apis::GkehubV1::Scope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Scope represents a Scope in a Fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scope

Returns a new instance of Scope.



6221
6222
6223
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the scope was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6177
6178
6179
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6177

def create_time
  @create_time
end

#delete_timeString

Output only. When the scope was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6182
6183
6184
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6182

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Scope. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6187
6188
6189
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6187

def labels
  @labels
end

#nameString

The resource name for the scope projects/project/locations/location/ scopes/scope` Corresponds to the JSON propertyname`

Returns:

  • (String)


6193
6194
6195
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6193

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Scope-level cluster namespace labels. For the member clusters bound to the Scope, these labels are applied to each namespace under the Scope. Scope-level labels take precedence over Namespace-level labels ( namespace_labels in the Fleet Namespace resource) if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


6202
6203
6204
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6202

def namespace_labels
  @namespace_labels
end

#stateGoogle::Apis::GkehubV1::ScopeLifecycleState

ScopeLifecycleState describes the state of a Scope resource. Corresponds to the JSON property state



6207
6208
6209
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6207

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all scope resources. If a scope resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6214
6215
6216
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6214

def uid
  @uid
end

#update_timeString

Output only. When the scope was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6219
6220
6221
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6219

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6226

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end