Class: Google::Apis::GkehubV1::ServiceMeshCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ServiceMeshCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshCondition
constructor
A new instance of ServiceMeshCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshCondition
Returns a new instance of ServiceMeshCondition.
6336 6337 6338 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6319 6320 6321 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6319 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6324 6325 6326 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6324 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6329 6330 6331 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6329 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6334 6335 6336 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6334 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6341 6342 6343 6344 6345 6346 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6341 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |