Class: Google::Apis::GkehubV1::ServiceMeshFeatureCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ServiceMeshFeatureCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshFeatureCondition
constructor
A new instance of ServiceMeshFeatureCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshFeatureCondition
Returns a new instance of ServiceMeshFeatureCondition.
6446 6447 6448 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6429 6430 6431 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6429 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6434 6435 6436 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6434 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6439 6440 6441 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6439 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6444 6445 6446 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6444 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6451 6452 6453 6454 6455 6456 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6451 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |