Class: Google::Apis::GkehubV1::ServiceMeshMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshMembershipSpec

Returns a new instance of ServiceMeshMembershipSpec.



6453
6454
6455
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


6440
6441
6442
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6440

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


6446
6447
6448
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6446

def control_plane
  @control_plane
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


6451
6452
6453
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6451

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6458
6459
6460
6461
6462
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6458

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @management = args[:management] if args.key?(:management)
end