Class: Google::Apis::GkehubV1::WorkloadIdentityFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

WorkloadIdentity: Global feature state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityFeatureState

Returns a new instance of WorkloadIdentityFeatureState.



6889
6890
6891
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_state_detailsHash<String,Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail>

The state of the IAM namespaces for the fleet. Corresponds to the JSON property namespaceStateDetails



6866
6867
6868
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6866

def namespace_state_details
  @namespace_state_details
end

#namespace_statesHash<String,String>

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property namespaceStates

Returns:

  • (Hash<String,String>)


6872
6873
6874
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6872

def namespace_states
  @namespace_states
end

#scope_tenancy_workload_identity_poolString

The full name of the scope-tenancy pool for the fleet. Corresponds to the JSON property scopeTenancyWorkloadIdentityPool

Returns:

  • (String)


6877
6878
6879
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6877

def scope_tenancy_workload_identity_pool
  @scope_tenancy_workload_identity_pool
end

#workload_identity_poolString

The full name of the svc.id.goog pool for the fleet. Corresponds to the JSON property workloadIdentityPool

Returns:

  • (String)


6882
6883
6884
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6882

def workload_identity_pool
  @workload_identity_pool
end

#workload_identity_pool_state_detailsHash<String,Google::Apis::GkehubV1::WorkloadIdentityWorkloadIdentityPoolStateDetail>

The state of the Workload Identity Pools for the fleet. Corresponds to the JSON property workloadIdentityPoolStateDetails



6887
6888
6889
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6887

def workload_identity_pool_state_details
  @workload_identity_pool_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6894
6895
6896
6897
6898
6899
6900
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6894

def update!(**args)
  @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details)
  @namespace_states = args[:namespace_states] if args.key?(:namespace_states)
  @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool)
  @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool)
  @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details)
end