Class: Google::Apis::GkehubV1::WorkloadIdentityMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityMembershipState

Returns a new instance of WorkloadIdentityMembershipState.



6845
6846
6847
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property description

Returns:

  • (String)


6838
6839
6840
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6838

def description
  @description
end

#identity_provider_state_detailsHash<String,Google::Apis::GkehubV1::WorkloadIdentityIdentityProviderStateDetail>

The state of the Identity Providers corresponding to the membership. Corresponds to the JSON property identityProviderStateDetails



6843
6844
6845
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6843

def identity_provider_state_details
  @identity_provider_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6850
6851
6852
6853
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6850

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details)
end