Class: Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
6870 6871 6872 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
6863 6864 6865 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6863 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
6868 6869 6870 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6868 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6875 6876 6877 6878 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6875 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |