Class: Google::Apis::GkehubV1::WorkloadIdentityWorkloadIdentityPoolStateDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail

Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.



6921
6922
6923
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The state of the Workload Identity Pool. Corresponds to the JSON property code

Returns:

  • (String)


6914
6915
6916
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6914

def code
  @code
end

#descriptionString

A human-readable description of the current state or returned error. Corresponds to the JSON property description

Returns:

  • (String)


6919
6920
6921
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6919

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6926
6927
6928
6929
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6926

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
end