Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

The state of ConfigSync's deployment on a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncDeploymentState

Returns a new instance of ConfigManagementConfigSyncDeploymentState.



1101
1102
1103
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Deployment state of admission-webhook Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1059
1060
1061
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1059

def admission_webhook
  @admission_webhook
end

#git_syncString

Deployment state of the git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1064

def git_sync
  @git_sync
end

#importerString

Deployment state of the importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1069

def importer
  @importer
end

#monitorString

Deployment state of the monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1074
1075
1076
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1074

def monitor
  @monitor
end

#otel_collectorString

Deployment state of otel-collector Corresponds to the JSON property otelCollector

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1079

def otel_collector
  @otel_collector
end

#reconciler_managerString

Deployment state of reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1084

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Deployment state of resource-group-controller-manager Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1089

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Deployment state of root-reconciler Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1094
1095
1096
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1094

def root_reconciler
  @root_reconciler
end

#syncerString

Deployment state of the syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1099
1100
1101
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1099

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1106

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end