Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

The state of ConfigSync's deployment on a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncDeploymentState

Returns a new instance of ConfigManagementConfigSyncDeploymentState.



1041
1042
1043
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Deployment state of admission-webhook Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


999
1000
1001
# File 'lib/google/apis/gkehub_v1/classes.rb', line 999

def admission_webhook
  @admission_webhook
end

#git_syncString

Deployment state of the git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1004
1005
1006
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1004

def git_sync
  @git_sync
end

#importerString

Deployment state of the importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1009
1010
1011
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1009

def importer
  @importer
end

#monitorString

Deployment state of the monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1014
1015
1016
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1014

def monitor
  @monitor
end

#otel_collectorString

Deployment state of otel-collector Corresponds to the JSON property otelCollector

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1019

def otel_collector
  @otel_collector
end

#reconciler_managerString

Deployment state of reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1024

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Deployment state of resource-group-controller-manager Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1029

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Deployment state of root-reconciler Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1034

def root_reconciler
  @root_reconciler
end

#syncerString

Deployment state of the syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1039

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1046

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end