Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

State information for ConfigSync

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncState

Returns a new instance of ConfigManagementConfigSyncState.



1129
1130
1131
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_level_stop_syncing_stateString

Output only. Whether syncing resources to the cluster is stopped at the cluster level. Corresponds to the JSON property clusterLevelStopSyncingState

Returns:

  • (String)


1086
1087
1088
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1086

def cluster_level_stop_syncing_state
  @cluster_level_stop_syncing_state
end

#cr_countFixnum

Output only. The number of RootSync and RepoSync CRs in the cluster. Corresponds to the JSON property crCount

Returns:

  • (Fixnum)


1091
1092
1093
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1091

def cr_count
  @cr_count
end

#deployment_stateGoogle::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState

The state of ConfigSync's deployment on a cluster Corresponds to the JSON property deploymentState



1096
1097
1098
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1096

def deployment_state
  @deployment_state
end

#errorsArray<Google::Apis::GkehubV1::ConfigManagementConfigSyncError>

Output only. Errors pertaining to the installation of Config Sync. Corresponds to the JSON property errors



1101
1102
1103
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1101

def errors
  @errors
end

#reposync_crdString

Output only. The state of the Reposync CRD Corresponds to the JSON property reposyncCrd

Returns:

  • (String)


1106
1107
1108
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1106

def reposync_crd
  @reposync_crd
end

#rootsync_crdString

Output only. The state of the RootSync CRD Corresponds to the JSON property rootsyncCrd

Returns:

  • (String)


1111
1112
1113
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1111

def rootsync_crd
  @rootsync_crd
end

#stateString

Output only. The state of CS This field summarizes the other fields in this message. Corresponds to the JSON property state

Returns:

  • (String)


1117
1118
1119
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1117

def state
  @state
end

#sync_stateGoogle::Apis::GkehubV1::ConfigManagementSyncState

State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property syncState



1122
1123
1124
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1122

def sync_state
  @sync_state
end

#versionGoogle::Apis::GkehubV1::ConfigManagementConfigSyncVersion

Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property version



1127
1128
1129
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1127

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1134

def update!(**args)
  @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state)
  @cr_count = args[:cr_count] if args.key?(:cr_count)
  @deployment_state = args[:deployment_state] if args.key?(:deployment_state)
  @errors = args[:errors] if args.key?(:errors)
  @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd)
  @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd)
  @state = args[:state] if args.key?(:state)
  @sync_state = args[:sync_state] if args.key?(:sync_state)
  @version = args[:version] if args.key?(:version)
end