Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ConfigManagementConfigSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
State information for ConfigSync
Instance Attribute Summary collapse
-
#cluster_level_stop_syncing_state ⇒ String
Output only.
-
#cr_count ⇒ Fixnum
Output only.
-
#deployment_state ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster Corresponds to the JSON property
deploymentState. -
#errors ⇒ Array<Google::Apis::GkehubV1::ConfigManagementConfigSyncError>
Output only.
-
#reposync_crd ⇒ String
Output only.
-
#rootsync_crd ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#sync_state ⇒ Google::Apis::GkehubV1::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property
syncState. -
#version ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementConfigSyncState
constructor
A new instance of ConfigManagementConfigSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementConfigSyncState
Returns a new instance of ConfigManagementConfigSyncState.
1107 1108 1109 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_level_stop_syncing_state ⇒ String
Output only. Whether syncing resources to the cluster is stopped at the
cluster level.
Corresponds to the JSON property clusterLevelStopSyncingState
1064 1065 1066 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1064 def cluster_level_stop_syncing_state @cluster_level_stop_syncing_state end |
#cr_count ⇒ Fixnum
Output only. The number of RootSync and RepoSync CRs in the cluster.
Corresponds to the JSON property crCount
1069 1070 1071 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1069 def cr_count @cr_count end |
#deployment_state ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster
Corresponds to the JSON property deploymentState
1074 1075 1076 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1074 def deployment_state @deployment_state end |
#errors ⇒ Array<Google::Apis::GkehubV1::ConfigManagementConfigSyncError>
Output only. Errors pertaining to the installation of Config Sync.
Corresponds to the JSON property errors
1079 1080 1081 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1079 def errors @errors end |
#reposync_crd ⇒ String
Output only. The state of the Reposync CRD
Corresponds to the JSON property reposyncCrd
1084 1085 1086 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1084 def reposync_crd @reposync_crd end |
#rootsync_crd ⇒ String
Output only. The state of the RootSync CRD
Corresponds to the JSON property rootsyncCrd
1089 1090 1091 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1089 def rootsync_crd @rootsync_crd end |
#state ⇒ String
Output only. The state of CS This field summarizes the other fields in this
message.
Corresponds to the JSON property state
1095 1096 1097 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1095 def state @state end |
#sync_state ⇒ Google::Apis::GkehubV1::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster
Corresponds to the JSON property syncState
1100 1101 1102 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1100 def sync_state @sync_state end |
#version ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods
Corresponds to the JSON property version
1105 1106 1107 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1105 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1112 def update!(**args) @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state) @cr_count = args[:cr_count] if args.key?(:cr_count) @deployment_state = args[:deployment_state] if args.key?(:deployment_state) @errors = args[:errors] if args.key?(:errors) @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd) @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd) @state = args[:state] if args.key?(:state) @sync_state = args[:sync_state] if args.key?(:sync_state) @version = args[:version] if args.key?(:version) end |