Class: Google::Apis::GkehubV1::ConfigManagementConfigSyncVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Specific versioning information pertaining to ConfigSync's Pods

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncVersion

Returns a new instance of ConfigManagementConfigSyncVersion.



1174
1175
1176
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Version of the deployed admission-webhook pod Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1132

def admission_webhook
  @admission_webhook
end

#git_syncString

Version of the deployed git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1137
1138
1139
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1137

def git_sync
  @git_sync
end

#importerString

Version of the deployed importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1142

def importer
  @importer
end

#monitorString

Version of the deployed monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1147
1148
1149
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1147

def monitor
  @monitor
end

#otel_collectorString

Version of the deployed otel-collector pod Corresponds to the JSON property otelCollector

Returns:

  • (String)


1152
1153
1154
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1152

def otel_collector
  @otel_collector
end

#reconciler_managerString

Version of the deployed reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1157
1158
1159
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1157

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Version of the deployed resource-group-controller-manager pod Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1162
1163
1164
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1162

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Version of the deployed reconciler container in root-reconciler pod Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1167
1168
1169
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1167

def root_reconciler
  @root_reconciler
end

#syncerString

Version of the deployed syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1172
1173
1174
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1172

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1179

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end