Class: Google::Apis::GkehubV1::ConfigManagementDeploymentOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration for a deployment override.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementDeploymentOverride

Returns a new instance of ConfigManagementDeploymentOverride.



1284
1285
1286
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::GkehubV1::ConfigManagementContainerOverride>

Optional. The containers of the deployment resource to be overridden. Corresponds to the JSON property containers



1272
1273
1274
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1272

def containers
  @containers
end

#deployment_nameString

Required. The name of the deployment resource to be overridden. Corresponds to the JSON property deploymentName

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1277

def deployment_name
  @deployment_name
end

#deployment_namespaceString

Required. The namespace of the deployment resource to be overridden. Corresponds to the JSON property deploymentNamespace

Returns:

  • (String)


1282
1283
1284
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1282

def deployment_namespace
  @deployment_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1289
1290
1291
1292
1293
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1289

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @deployment_name = args[:deployment_name] if args.key?(:deployment_name)
  @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace)
end