Class: Google::Apis::GkehubV1::ConfigManagementDeploymentOverride
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ConfigManagementDeploymentOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Configuration for a deployment override.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::GkehubV1::ConfigManagementContainerOverride>
Optional.
-
#deployment_name ⇒ String
Required.
-
#deployment_namespace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
constructor
A new instance of ConfigManagementDeploymentOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
Returns a new instance of ConfigManagementDeploymentOverride.
1254 1255 1256 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::GkehubV1::ConfigManagementContainerOverride>
Optional. The containers of the deployment resource to be overridden.
Corresponds to the JSON property containers
1242 1243 1244 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1242 def containers @containers end |
#deployment_name ⇒ String
Required. The name of the deployment resource to be overridden.
Corresponds to the JSON property deploymentName
1247 1248 1249 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1247 def deployment_name @deployment_name end |
#deployment_namespace ⇒ String
Required. The namespace of the deployment resource to be overridden.
Corresponds to the JSON property deploymentNamespace
1252 1253 1254 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1252 def deployment_namespace @deployment_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1259 1260 1261 1262 1263 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1259 def update!(**args) @containers = args[:containers] if args.key?(:containers) @deployment_name = args[:deployment_name] if args.key?(:deployment_name) @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace) end |