Class: Google::Apis::GkehubV1::ConfigManagementGitConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Git repo configuration for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementGitConfig

Returns a new instance of ConfigManagementGitConfig.



1383
1384
1385
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcp_service_account_emailString

Optional. The Google Cloud Service Account Email used for auth when secret_type is gcpServiceAccount. Corresponds to the JSON property gcpServiceAccountEmail

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1342

def 
  @gcp_service_account_email
end

#https_proxyString

Optional. URL for the HTTPS proxy to be used when communicating with the Git repo. Corresponds to the JSON property httpsProxy

Returns:

  • (String)


1348
1349
1350
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1348

def https_proxy
  @https_proxy
end

#policy_dirString

Optional. The path within the Git repository that represents the top level of the repo to sync. Default: the root directory of the repository. Corresponds to the JSON property policyDir

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1354

def policy_dir
  @policy_dir
end

#secret_typeString

Required. Type of secret configured for access to the Git repo. Must be one of ssh, cookiefile, gcenode, token, gcpserviceaccount, githubapp or none. The validation of this is case-sensitive. Corresponds to the JSON property secretType

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1361

def secret_type
  @secret_type
end

#sync_branchString

Optional. The branch of the repository to sync from. Default: master. Corresponds to the JSON property syncBranch

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1366

def sync_branch
  @sync_branch
end

#sync_repoString

Required. The URL of the Git repository to use as the source of truth. Corresponds to the JSON property syncRepo

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1371

def sync_repo
  @sync_repo
end

#sync_revString

Optional. Git revision (tag or hash) to check out. Default HEAD. Corresponds to the JSON property syncRev

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1376

def sync_rev
  @sync_rev
end

#sync_wait_secsFixnum

Optional. Period in seconds between consecutive syncs. Default: 15. Corresponds to the JSON property syncWaitSecs

Returns:

  • (Fixnum)


1381
1382
1383
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1381

def sync_wait_secs
  @sync_wait_secs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1388

def update!(**args)
  @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email)
  @https_proxy = args[:https_proxy] if args.key?(:https_proxy)
  @policy_dir = args[:policy_dir] if args.key?(:policy_dir)
  @secret_type = args[:secret_type] if args.key?(:secret_type)
  @sync_branch = args[:sync_branch] if args.key?(:sync_branch)
  @sync_repo = args[:sync_repo] if args.key?(:sync_repo)
  @sync_rev = args[:sync_rev] if args.key?(:sync_rev)
  @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs)
end