Class: Google::Apis::GkehubV1::ConfigManagementMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ConfigManagementMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Optional.
-
#config_sync ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSync
Configuration for Config Sync Corresponds to the JSON property
configSync. -
#hierarchy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller Corresponds to the JSON property
hierarchyController. -
#management ⇒ String
Optional.
-
#policy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementPolicyController
Configuration for Policy Controller Corresponds to the JSON property
policyController. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementMembershipSpec
constructor
A new instance of ConfigManagementMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementMembershipSpec
Returns a new instance of ConfigManagementMembershipSpec.
1702 1703 1704 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Optional. User-specified cluster name used by the Config Sync cluster-name-
selector annotation or ClusterSelector object, for applying configs to only a
subset of clusters. Read more about the cluster-name-selector annotation and
ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/
config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this
field if a name different from the cluster's fleet membership name is used by
the Config Sync cluster-name-selector annotation or ClusterSelector.
Corresponds to the JSON property cluster
1669 1670 1671 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1669 def cluster @cluster end |
#config_sync ⇒ Google::Apis::GkehubV1::ConfigManagementConfigSync
Configuration for Config Sync
Corresponds to the JSON property configSync
1674 1675 1676 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1674 def config_sync @config_sync end |
#hierarchy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller
Corresponds to the JSON property hierarchyController
1679 1680 1681 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1679 def hierarchy_controller @hierarchy_controller end |
#management ⇒ String
Optional. Deprecated: In Preview, automatic Feature management is unavailable
from version 1.21.0 onwards, and Config Sync only supports manual upgrades. If
set to manual upgrades, clear this field instead, which is behaviorally
equivalent.
Corresponds to the JSON property management
1687 1688 1689 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1687 def management @management end |
#policy_controller ⇒ Google::Apis::GkehubV1::ConfigManagementPolicyController
Configuration for Policy Controller
Corresponds to the JSON property policyController
1692 1693 1694 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1692 def policy_controller @policy_controller end |
#version ⇒ String
Optional. Version of Config Sync to install. Defaults to the latest supported
Config Sync version if the config_sync field is enabled. See supported
versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get-
support-config-sync#version_support_policy.
Corresponds to the JSON property version
1700 1701 1702 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1700 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1707 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @config_sync = args[:config_sync] if args.key?(:config_sync) @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller) @management = args[:management] if args.key?(:management) @policy_controller = args[:policy_controller] if args.key?(:policy_controller) @version = args[:version] if args.key?(:version) end |