Class: Google::Apis::GkehubV1::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1599
1600
1601
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Optional. The user-specified cluster name used by Config Sync cluster-name- selector annotation or ClusterSelector, for applying configs to only a subset of clusters. Omit this field if the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Set this field if a name different from the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1572
1573
1574
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1572

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1577
1578
1579
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1577

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1582
1583
1584
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1582

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Enables automatic Feature management. Corresponds to the JSON property management

Returns:

  • (String)


1587
1588
1589
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1587

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1592
1593
1594
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1592

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of ACM installed. Corresponds to the JSON property version

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1597

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1604
1605
1606
1607
1608
1609
1610
1611
# File 'lib/google/apis/gkehub_v1/classes.rb', line 1604

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end