Class: Google::Apis::GkehubV1::ConfigManagementSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ConfigManagementSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
State indicating an ACM's progress syncing configurations to a cluster
Instance Attribute Summary collapse
-
#code ⇒ String
Sync status code Corresponds to the JSON property
code. -
#errors ⇒ Array<Google::Apis::GkehubV1::ConfigManagementSyncError>
A list of errors resulting from problematic configs.
-
#import_token ⇒ String
Token indicating the state of the importer.
-
#last_sync ⇒ String
Deprecated: use last_sync_time instead.
-
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property
lastSyncTime. -
#source_token ⇒ String
Token indicating the state of the repo.
-
#sync_token ⇒ String
Token indicating the state of the syncer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementSyncState
constructor
A new instance of ConfigManagementSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementSyncState
Returns a new instance of ConfigManagementSyncState.
2113 2114 2115 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Sync status code
Corresponds to the JSON property code
2077 2078 2079 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2077 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1::ConfigManagementSyncError>
A list of errors resulting from problematic configs. This list will be
truncated after 100 errors, although it is unlikely for that many errors to
simultaneously exist.
Corresponds to the JSON property errors
2084 2085 2086 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2084 def errors @errors end |
#import_token ⇒ String
Token indicating the state of the importer.
Corresponds to the JSON property importToken
2089 2090 2091 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2089 def import_token @import_token end |
#last_sync ⇒ String
Deprecated: use last_sync_time instead. Timestamp of when ACM last
successfully synced the repo The time format is specified in https://golang.
org/pkg/time/#Time.String
Corresponds to the JSON property lastSync
2096 2097 2098 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2096 def last_sync @last_sync end |
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo
Corresponds to the JSON property lastSyncTime
2101 2102 2103 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2101 def last_sync_time @last_sync_time end |
#source_token ⇒ String
Token indicating the state of the repo.
Corresponds to the JSON property sourceToken
2106 2107 2108 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2106 def source_token @source_token end |
#sync_token ⇒ String
Token indicating the state of the syncer.
Corresponds to the JSON property syncToken
2111 2112 2113 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2111 def sync_token @sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2118 2119 2120 2121 2122 2123 2124 2125 2126 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2118 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) @import_token = args[:import_token] if args.key?(:import_token) @last_sync = args[:last_sync] if args.key?(:last_sync) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @source_token = args[:source_token] if args.key?(:source_token) @sync_token = args[:sync_token] if args.key?(:sync_token) end |