Class: Google::Apis::GkehubV1::ConfigManagementSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

State indicating an ACM's progress syncing configurations to a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncState

Returns a new instance of ConfigManagementSyncState.



2105
2106
2107
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Sync status code Corresponds to the JSON property code

Returns:

  • (String)


2069
2070
2071
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2069

def code
  @code
end

#errorsArray<Google::Apis::GkehubV1::ConfigManagementSyncError>

A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist. Corresponds to the JSON property errors



2076
2077
2078
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2076

def errors
  @errors
end

#import_tokenString

Token indicating the state of the importer. Corresponds to the JSON property importToken

Returns:

  • (String)


2081
2082
2083
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2081

def import_token
  @import_token
end

#last_syncString

Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang. org/pkg/time/#Time.String Corresponds to the JSON property lastSync

Returns:

  • (String)


2088
2089
2090
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2088

def last_sync
  @last_sync
end

#last_sync_timeString

Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2093

def last_sync_time
  @last_sync_time
end

#source_tokenString

Token indicating the state of the repo. Corresponds to the JSON property sourceToken

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2098

def source_token
  @source_token
end

#sync_tokenString

Token indicating the state of the syncer. Corresponds to the JSON property syncToken

Returns:

  • (String)


2103
2104
2105
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2103

def sync_token
  @sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2110
2111
2112
2113
2114
2115
2116
2117
2118
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2110

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @errors = args[:errors] if args.key?(:errors)
  @import_token = args[:import_token] if args.key?(:import_token)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @source_token = args[:source_token] if args.key?(:source_token)
  @sync_token = args[:sync_token] if args.key?(:sync_token)
end