Class: Google::Apis::GkehubV1::ConnectAgentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

ConnectAgentResource represents a Kubernetes resource manifest for Connect Agent deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectAgentResource

Returns a new instance of ConnectAgentResource.



2034
2035
2036
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#manifestString

YAML manifest of the resource. Corresponds to the JSON property manifest

Returns:

  • (String)


2026
2027
2028
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2026

def manifest
  @manifest
end

#typeGoogle::Apis::GkehubV1::TypeMeta

TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest. Corresponds to the JSON property type



2032
2033
2034
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2032

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2039
2040
2041
2042
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2039

def update!(**args)
  @manifest = args[:manifest] if args.key?(:manifest)
  @type = args[:type] if args.key?(:type)
end