Class: Google::Apis::GkehubV1::Feature
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Feature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Feature represents the settings and status of any Fleet Feature.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#fleet_default_member_config ⇒ Google::Apis::GkehubV1::CommonFleetDefaultMemberConfigSpec
CommonFleetDefaultMemberConfigSpec contains default configuration information for memberships of a fleet Corresponds to the JSON property
fleetDefaultMemberConfig. -
#labels ⇒ Hash<String,String>
Labels for this Feature.
-
#membership_specs ⇒ Hash<String,Google::Apis::GkehubV1::MembershipFeatureSpec>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1::MembershipFeatureState>
Output only.
-
#name ⇒ String
Output only.
-
#resource_state ⇒ Google::Apis::GkehubV1::FeatureResourceState
FeatureResourceState describes the state of a Feature resource in the GkeHub API.
-
#scope_specs ⇒ Hash<String,Google::Apis::GkehubV1::ScopeFeatureSpec>
Optional.
-
#scope_states ⇒ Hash<String,Google::Apis::GkehubV1::ScopeFeatureState>
Output only.
-
#spec ⇒ Google::Apis::GkehubV1::CommonFeatureSpec
CommonFeatureSpec contains Fleet-wide configuration information Corresponds to the JSON property
spec. -
#state ⇒ Google::Apis::GkehubV1::CommonFeatureState
CommonFeatureState contains Fleet-wide Feature status information.
-
#unreachable ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Feature
constructor
A new instance of Feature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Feature
Returns a new instance of Feature.
2403 2404 2405 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the Feature resource was created.
Corresponds to the JSON property createTime
2303 2304 2305 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2303 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the Feature resource was deleted.
Corresponds to the JSON property deleteTime
2308 2309 2310 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2308 def delete_time @delete_time end |
#fleet_default_member_config ⇒ Google::Apis::GkehubV1::CommonFleetDefaultMemberConfigSpec
CommonFleetDefaultMemberConfigSpec contains default configuration information
for memberships of a fleet
Corresponds to the JSON property fleetDefaultMemberConfig
2314 2315 2316 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2314 def fleet_default_member_config @fleet_default_member_config end |
#labels ⇒ Hash<String,String>
Labels for this Feature.
Corresponds to the JSON property labels
2319 2320 2321 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2319 def labels @labels end |
#membership_specs ⇒ Hash<String,Google::Apis::GkehubV1::MembershipFeatureSpec>
Optional. Membership-specific configuration for this Feature. If this Feature
does not support any per-Membership configuration, this field may be unused.
The keys indicate which Membership the configuration is for, in the form:
projects/p/locations/l/memberships/m`Wherepis the project,lis a
valid location andmis a valid Membership in this project at that location.
pWILL match the Feature's project.pwill always be returned as the
project number, but the project ID is also accepted during input. If the same
Membership is specified in the map twice (using the project ID form, and the
project number form), exactly ONE of the entries will be saved, with no
guarantees as to which. For this reason, it is recommended the same format be
used for all entries when mutating a Feature.
Corresponds to the JSON propertymembershipSpecs`
2334 2335 2336 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2334 def membership_specs @membership_specs end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1::MembershipFeatureState>
Output only. Membership-specific Feature status. If this Feature does report
any per-Membership status, this field may be unused. The keys indicate which
Membership the state is for, in the form: projects/p/locations/l/
memberships/m`Wherepis the project number,lis a valid location and
mis a valid Membership in this project at that location.pMUST match the
Feature's project number.
Corresponds to the JSON propertymembershipStates`
2344 2345 2346 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2344 def membership_states @membership_states end |
#name ⇒ String
Output only. The full, unique name of this Feature resource in the format
projects/*/locations/*/features/*.
Corresponds to the JSON property name
2350 2351 2352 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2350 def name @name end |
#resource_state ⇒ Google::Apis::GkehubV1::FeatureResourceState
FeatureResourceState describes the state of a Feature resource in the GkeHub
API. See FeatureState for the "running state" of the Feature in the Fleet
and across Memberships.
Corresponds to the JSON property resourceState
2357 2358 2359 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2357 def resource_state @resource_state end |
#scope_specs ⇒ Hash<String,Google::Apis::GkehubV1::ScopeFeatureSpec>
Optional. Scope-specific configuration for this Feature. If this Feature does
not support any per-Scope configuration, this field may be unused. The keys
indicate which Scope the configuration is for, in the form: projects/p/
locations/global/scopes/s`Wherepis the project,sis a valid Scope in
this project.pWILL match the Feature's project.pwill always be
returned as the project number, but the project ID is also accepted during
input. If the same Scope is specified in the map twice (using the project ID
form, and the project number form), exactly ONE of the entries will be saved,
with no guarantees as to which. For this reason, it is recommended the same
format be used for all entries when mutating a Feature.
Corresponds to the JSON propertyscopeSpecs`
2371 2372 2373 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2371 def scope_specs @scope_specs end |
#scope_states ⇒ Hash<String,Google::Apis::GkehubV1::ScopeFeatureState>
Output only. Scope-specific Feature status. If this Feature does report any
per-Scope status, this field may be unused. The keys indicate which Scope the
state is for, in the form: projects/p/locations/global/scopes/s`Wherep
is the project,sis a valid Scope in this project.pWILL match the
Feature's project.
Corresponds to the JSON propertyscopeStates`
2380 2381 2382 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2380 def scope_states @scope_states end |
#spec ⇒ Google::Apis::GkehubV1::CommonFeatureSpec
CommonFeatureSpec contains Fleet-wide configuration information
Corresponds to the JSON property spec
2385 2386 2387 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2385 def spec @spec end |
#state ⇒ Google::Apis::GkehubV1::CommonFeatureState
CommonFeatureState contains Fleet-wide Feature status information.
Corresponds to the JSON property state
2390 2391 2392 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2390 def state @state end |
#unreachable ⇒ Array<String>
Output only. List of locations that could not be reached while fetching this
feature.
Corresponds to the JSON property unreachable
2396 2397 2398 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2396 def unreachable @unreachable end |
#update_time ⇒ String
Output only. When the Feature resource was last updated.
Corresponds to the JSON property updateTime
2401 2402 2403 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2401 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2408 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @fleet_default_member_config = args[:fleet_default_member_config] if args.key?(:fleet_default_member_config) @labels = args[:labels] if args.key?(:labels) @membership_specs = args[:membership_specs] if args.key?(:membership_specs) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @resource_state = args[:resource_state] if args.key?(:resource_state) @scope_specs = args[:scope_specs] if args.key?(:scope_specs) @scope_states = args[:scope_states] if args.key?(:scope_states) @spec = args[:spec] if args.key?(:spec) @state = args[:state] if args.key?(:state) @unreachable = args[:unreachable] if args.key?(:unreachable) @update_time = args[:update_time] if args.key?(:update_time) end |