Class: Google::Apis::GkehubV1::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2437
2438
2439
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2435

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2442
2443
2444
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2442

def update!(**args)
  @state = args[:state] if args.key?(:state)
end