Class: Google::Apis::GkehubV1::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2429
2430
2431
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2427
2428
2429
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2427

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2434
2435
2436
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2434

def update!(**args)
  @state = args[:state] if args.key?(:state)
end