Class: Google::Apis::GkehubV1::FleetObservabilityFleetObservabilityBaseFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::FleetObservabilityFleetObservabilityBaseFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Base state for fleet observability feature.
Instance Attribute Summary collapse
-
#code ⇒ String
The high-level, machine-readable status of this Feature.
-
#errors ⇒ Array<Google::Apis::GkehubV1::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not OK.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
constructor
A new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
Returns a new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
2650 2651 2652 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The high-level, machine-readable status of this Feature.
Corresponds to the JSON property code
2642 2643 2644 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2642 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not
OK.
Corresponds to the JSON property errors
2648 2649 2650 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2648 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2655 2656 2657 2658 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2655 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) end |