Class: Google::Apis::GkehubV1::FleetObservabilityFleetObservabilityBaseFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::FleetObservabilityFleetObservabilityBaseFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Base state for fleet observability feature.
Instance Attribute Summary collapse
-
#code ⇒ String
The high-level, machine-readable status of this Feature.
-
#errors ⇒ Array<Google::Apis::GkehubV1::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not OK.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
constructor
A new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FleetObservabilityFleetObservabilityBaseFeatureState
Returns a new instance of FleetObservabilityFleetObservabilityBaseFeatureState.
2553 2554 2555 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The high-level, machine-readable status of this Feature.
Corresponds to the JSON property code
2545 2546 2547 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2545 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1::FleetObservabilityFeatureError>
Errors after reconciling the monitoring and logging feature if the code is not
OK.
Corresponds to the JSON property errors
2551 2552 2553 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2551 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2558 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) end |