Class: Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Configuration options for the AIS diagnostic interface.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Determines whether to enable the diagnostic interface.
-
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
constructor
A new instance of IdentityServiceDiagnosticInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
Returns a new instance of IdentityServiceDiagnosticInterface.
3035 3036 3037 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Determines whether to enable the diagnostic interface.
Corresponds to the JSON property enabled
3026 3027 3028 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3026 def enabled @enabled end |
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement. When
reached, requests to the interface would be automatically rejected.
Corresponds to the JSON property expirationTime
3033 3034 3035 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3033 def expiration_time @expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3040 3041 3042 3043 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3040 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) end |