Class: Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration options for the AIS diagnostic interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceDiagnosticInterface

Returns a new instance of IdentityServiceDiagnosticInterface.



2919
2920
2921
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Determines whether to enable the diagnostic interface. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2910
2911
2912
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2910

def enabled
  @enabled
end

#expiration_timeString

Determines the expiration time of the diagnostic interface enablement. When reached, requests to the interface would be automatically rejected. Corresponds to the JSON property expirationTime

Returns:

  • (String)


2917
2918
2919
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2917

def expiration_time
  @expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2924
2925
2926
2927
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2924

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
end