Class: Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::IdentityServiceDiagnosticInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Configuration options for the AIS diagnostic interface.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Determines whether to enable the diagnostic interface.
-
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
constructor
A new instance of IdentityServiceDiagnosticInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
Returns a new instance of IdentityServiceDiagnosticInterface.
2919 2920 2921 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Determines whether to enable the diagnostic interface.
Corresponds to the JSON property enabled
2910 2911 2912 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2910 def enabled @enabled end |
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement. When
reached, requests to the interface would be automatically rejected.
Corresponds to the JSON property expirationTime
2917 2918 2919 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2917 def expiration_time @expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2924 2925 2926 2927 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 2924 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) end |