Class: Google::Apis::GkehubV1::IdentityServiceGroupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Contains the properties for locating and authenticating groups in the directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceGroupConfig

Returns a new instance of IdentityServiceGroupConfig.



3100
3101
3102
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_dnString

Required. The location of the subtree in the LDAP directory to search for group entries. Corresponds to the JSON property baseDn

Returns:

  • (String)


3083
3084
3085
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3083

def base_dn
  @base_dn
end

#filterString

Optional. Optional filter to be used when searching for groups a user belongs to. This can be used to explicitly match only certain groups in order to reduce the amount of groups returned for each user. This defaults to "( objectClass=Group)". Corresponds to the JSON property filter

Returns:

  • (String)


3091
3092
3093
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3091

def filter
  @filter
end

#id_attributeString

Optional. The identifying name of each group a user belongs to. For example, if this is set to "distinguishedName" then RBACs and other group expectations should be written as full DNs. This defaults to "distinguishedName". Corresponds to the JSON property idAttribute

Returns:

  • (String)


3098
3099
3100
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3098

def id_attribute
  @id_attribute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3105
3106
3107
3108
3109
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3105

def update!(**args)
  @base_dn = args[:base_dn] if args.key?(:base_dn)
  @filter = args[:filter] if args.key?(:filter)
  @id_attribute = args[:id_attribute] if args.key?(:id_attribute)
end