Class: Google::Apis::GkehubV1::IdentityServiceGroupConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::IdentityServiceGroupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Contains the properties for locating and authenticating groups in the directory.
Instance Attribute Summary collapse
-
#base_dn ⇒ String
Required.
-
#filter ⇒ String
Optional.
-
#id_attribute ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceGroupConfig
constructor
A new instance of IdentityServiceGroupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceGroupConfig
Returns a new instance of IdentityServiceGroupConfig.
3092 3093 3094 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3092 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_dn ⇒ String
Required. The location of the subtree in the LDAP directory to search for
group entries.
Corresponds to the JSON property baseDn
3075 3076 3077 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3075 def base_dn @base_dn end |
#filter ⇒ String
Optional. Optional filter to be used when searching for groups a user belongs
to. This can be used to explicitly match only certain groups in order to
reduce the amount of groups returned for each user. This defaults to "(
objectClass=Group)".
Corresponds to the JSON property filter
3083 3084 3085 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3083 def filter @filter end |
#id_attribute ⇒ String
Optional. The identifying name of each group a user belongs to. For example,
if this is set to "distinguishedName" then RBACs and other group expectations
should be written as full DNs. This defaults to "distinguishedName".
Corresponds to the JSON property idAttribute
3090 3091 3092 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3090 def id_attribute @id_attribute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3097 3098 3099 3100 3101 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3097 def update!(**args) @base_dn = args[:base_dn] if args.key?(:base_dn) @filter = args[:filter] if args.key?(:filter) @id_attribute = args[:id_attribute] if args.key?(:id_attribute) end |