Class: Google::Apis::GkehubV1::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



3165
3166
3167
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV1::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



3146
3147
3148
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3146

def group
  @group
end

#serverGoogle::Apis::GkehubV1::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



3151
3152
3153
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3151

def server
  @server
end

#service_accountGoogle::Apis::GkehubV1::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



3158
3159
3160
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3158

def 
  @service_account
end

#userGoogle::Apis::GkehubV1::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



3163
3164
3165
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3163

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3170
3171
3172
3173
3174
3175
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3170

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end