Class: Google::Apis::GkehubV1::IdentityServiceLdapConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::IdentityServiceLdapConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Configuration for the LDAP Auth flow.
Instance Attribute Summary collapse
-
#group ⇒ Google::Apis::GkehubV1::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the directory.
-
#server ⇒ Google::Apis::GkehubV1::IdentityServiceServerConfig
Server settings for the external LDAP server.
-
#service_account ⇒ Google::Apis::GkehubV1::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory.
-
#user ⇒ Google::Apis::GkehubV1::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceLdapConfig
constructor
A new instance of IdentityServiceLdapConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceLdapConfig
Returns a new instance of IdentityServiceLdapConfig.
3040 3041 3042 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ Google::Apis::GkehubV1::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the
directory.
Corresponds to the JSON property group
3021 3022 3023 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3021 def group @group end |
#server ⇒ Google::Apis::GkehubV1::IdentityServiceServerConfig
Server settings for the external LDAP server.
Corresponds to the JSON property server
3026 3027 3028 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3026 def server @server end |
#service_account ⇒ Google::Apis::GkehubV1::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform
the LDAP search in the directory. The credentials can be supplied by the
combination of the DN and password or the client certificate.
Corresponds to the JSON property serviceAccount
3033 3034 3035 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3033 def service_account @service_account end |
#user ⇒ Google::Apis::GkehubV1::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Corresponds to the JSON property user
3038 3039 3040 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3038 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3045 3046 3047 3048 3049 3050 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3045 def update!(**args) @group = args[:group] if args.key?(:group) @server = args[:server] if args.key?(:server) @service_account = args[:service_account] if args.key?(:service_account) @user = args[:user] if args.key?(:user) end |