Class: Google::Apis::GkehubV1::IdentityServiceSamlConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::IdentityServiceSamlConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Configuration for the SAML Auth flow.
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Hash<String,String>
Optional.
-
#group_prefix ⇒ String
Optional.
-
#groups_attribute ⇒ String
Optional.
-
#identity_provider_certificates ⇒ Array<String>
Required.
-
#identity_provider_id ⇒ String
Required.
-
#identity_provider_sso_uri ⇒ String
Required.
-
#user_attribute ⇒ String
Optional.
-
#user_prefix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceSamlConfig
constructor
A new instance of IdentityServiceSamlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceSamlConfig
Returns a new instance of IdentityServiceSamlConfig.
3394 3395 3396 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_mapping ⇒ Hash<String,String>
Optional. The mapping of additional user attributes like nickname, birthday
and address etc.. key is the name of this additional attribute. value is a
string presenting as CEL(common expression language, go/cel) used for getting
the value from the resources. Take nickname as an example, in this case, key
is "attribute.nickname" and value is "assertion.nickname".
Corresponds to the JSON property attributeMapping
3352 3353 3354 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3352 def attribute_mapping @attribute_mapping end |
#group_prefix ⇒ String
Optional. Prefix to prepend to group name.
Corresponds to the JSON property groupPrefix
3357 3358 3359 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3357 def group_prefix @group_prefix end |
#groups_attribute ⇒ String
Optional. The SAML attribute to read groups from. This value is expected to be
a string and will be passed along as-is (with the option of being prefixed by
the group_prefix).
Corresponds to the JSON property groupsAttribute
3364 3365 3366 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3364 def groups_attribute @groups_attribute end |
#identity_provider_certificates ⇒ Array<String>
Required. The list of IdP certificates to validate the SAML response against.
Corresponds to the JSON property identityProviderCertificates
3369 3370 3371 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3369 def identity_provider_certificates @identity_provider_certificates end |
#identity_provider_id ⇒ String
Required. The entity ID of the SAML IdP.
Corresponds to the JSON property identityProviderId
3374 3375 3376 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3374 def identity_provider_id @identity_provider_id end |
#identity_provider_sso_uri ⇒ String
Required. The URI where the SAML IdP exposes the SSO service.
Corresponds to the JSON property identityProviderSsoUri
3379 3380 3381 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3379 def identity_provider_sso_uri @identity_provider_sso_uri end |
#user_attribute ⇒ String
Optional. The SAML attribute to read username from. If unspecified, the
username will be read from the NameID element of the assertion in SAML
response. This value is expected to be a string and will be passed along as-is
(with the option of being prefixed by the user_prefix).
Corresponds to the JSON property userAttribute
3387 3388 3389 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3387 def user_attribute @user_attribute end |
#user_prefix ⇒ String
Optional. Prefix to prepend to user name.
Corresponds to the JSON property userPrefix
3392 3393 3394 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3392 def user_prefix @user_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3399 def update!(**args) @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping) @group_prefix = args[:group_prefix] if args.key?(:group_prefix) @groups_attribute = args[:groups_attribute] if args.key?(:groups_attribute) @identity_provider_certificates = args[:identity_provider_certificates] if args.key?(:identity_provider_certificates) @identity_provider_id = args[:identity_provider_id] if args.key?(:identity_provider_id) @identity_provider_sso_uri = args[:identity_provider_sso_uri] if args.key?(:identity_provider_sso_uri) @user_attribute = args[:user_attribute] if args.key?(:user_attribute) @user_prefix = args[:user_prefix] if args.key?(:user_prefix) end |