Class: Google::Apis::GkehubV1::IdentityServiceServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceServiceAccountConfig

Returns a new instance of IdentityServiceServiceAccountConfig.



3338
3339
3340
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#simple_bind_credentialsGoogle::Apis::GkehubV1::IdentityServiceSimpleBindCredentials

The structure holds the LDAP simple binding credential. Corresponds to the JSON property simpleBindCredentials



3336
3337
3338
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3336

def simple_bind_credentials
  @simple_bind_credentials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3343
3344
3345
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3343

def update!(**args)
  @simple_bind_credentials = args[:simple_bind_credentials] if args.key?(:simple_bind_credentials)
end