Class: Google::Apis::GkehubV1::ListBoundMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListBoundMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of Memberships bound to a Scope.
Instance Attribute Summary collapse
-
#memberships ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of Memberships bound to the given Scope.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListBoundMembershipsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBoundMembershipsResponse
constructor
A new instance of ListBoundMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBoundMembershipsResponse
Returns a new instance of ListBoundMembershipsResponse.
3684 3685 3686 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memberships ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of Memberships bound to the given Scope.
Corresponds to the JSON property memberships
3670 3671 3672 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3670 def memberships @memberships end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListBoundMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3677 3678 3679 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3677 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3682 3683 3684 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3682 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3689 3690 3691 3692 3693 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3689 def update!(**args) @memberships = args[:memberships] if args.key?(:memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |