Class: Google::Apis::GkehubV1::ListFeaturesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListFeaturesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Response message for the GkeHub.ListFeatures method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListFeaturesmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1::Feature>
The list of matching Features Corresponds to the JSON property
resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFeaturesResponse
constructor
A new instance of ListFeaturesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFeaturesResponse
Returns a new instance of ListFeaturesResponse.
3721 3722 3723 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListFeatures method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3714 3715 3716 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3714 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1::Feature>
The list of matching Features
Corresponds to the JSON property resources
3719 3720 3721 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3719 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3726 3727 3728 3729 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3726 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) end |