Class: Google::Apis::GkehubV1::ListFeaturesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListFeaturesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Response message for the GkeHub.ListFeatures method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListFeaturesmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1::Feature>
The list of matching Features Corresponds to the JSON property
resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFeaturesResponse
constructor
A new instance of ListFeaturesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFeaturesResponse
Returns a new instance of ListFeaturesResponse.
3711 3712 3713 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListFeatures method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3704 3705 3706 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3704 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1::Feature>
The list of matching Features
Corresponds to the JSON property resources
3709 3710 3711 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3709 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3716 3717 3718 3719 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3716 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) end |