Class: Google::Apis::GkehubV1::ListFeaturesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Response message for the GkeHub.ListFeatures method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFeaturesResponse

Returns a new instance of ListFeaturesResponse.



3705
3706
3707
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListFeatures method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3698
3699
3700
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3698

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1::Feature>

The list of matching Features Corresponds to the JSON property resources



3703
3704
3705
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3703

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3710
3711
3712
3713
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3710

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end