Class: Google::Apis::GkehubV1::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipBindingsResponse

Returns a new instance of ListMembershipBindingsResponse.



3797
3798
3799
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_bindingsArray<Google::Apis::GkehubV1::MembershipBinding>

The list of membership_bindings Corresponds to the JSON property membershipBindings



3783
3784
3785
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3783

def membership_bindings
  @membership_bindings
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3790
3791
3792
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3790

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3795
3796
3797
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3795

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3802
3803
3804
3805
3806
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3802

def update!(**args)
  @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end