Class: Google::Apis::GkehubV1::ListMembershipBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of MembershipBindings.
Instance Attribute Summary collapse
-
#membership_bindings ⇒ Array<Google::Apis::GkehubV1::MembershipBinding>
The list of membership_bindings Corresponds to the JSON property
membershipBindings. -
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipBindingsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipBindingsResponse
constructor
A new instance of ListMembershipBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipBindingsResponse
Returns a new instance of ListMembershipBindingsResponse.
3795 3796 3797 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership_bindings ⇒ Array<Google::Apis::GkehubV1::MembershipBinding>
The list of membership_bindings
Corresponds to the JSON property membershipBindings
3781 3782 3783 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3781 def membership_bindings @membership_bindings end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListMembershipBindings
method. The value of an empty string means that there are no more resources
to return.
Corresponds to the JSON property nextPageToken
3788 3789 3790 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3788 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3793 3794 3795 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3793 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3800 3801 3802 3803 3804 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3800 def update!(**args) @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |