Class: Google::Apis::GkehubV1::ListMembershipBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of MembershipBindings.
Instance Attribute Summary collapse
-
#membership_bindings ⇒ Array<Google::Apis::GkehubV1::MembershipBinding>
The list of membership_bindings Corresponds to the JSON property
membershipBindings. -
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipBindingsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipBindingsResponse
constructor
A new instance of ListMembershipBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipBindingsResponse
Returns a new instance of ListMembershipBindingsResponse.
3673 3674 3675 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership_bindings ⇒ Array<Google::Apis::GkehubV1::MembershipBinding>
The list of membership_bindings
Corresponds to the JSON property membershipBindings
3659 3660 3661 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3659 def membership_bindings @membership_bindings end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListMembershipBindings
method. The value of an empty string means that there are no more resources
to return.
Corresponds to the JSON property nextPageToken
3666 3667 3668 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3666 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3671 3672 3673 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3671 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3678 3679 3680 3681 3682 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3678 def update!(**args) @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |