Class: Google::Apis::GkehubV1::ListMembershipRbacRoleBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipRbacRoleBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of Membership RBACRoleBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindingsmethod. -
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1::RbacRoleBinding>
The list of Membership RBACRoleBindings.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
constructor
A new instance of ListMembershipRbacRoleBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
Returns a new instance of ListMembershipRbacRoleBindingsResponse.
3831 3832 3833 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindings method. The value of an empty string means
that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3819 3820 3821 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3819 def next_page_token @next_page_token end |
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1::RbacRoleBinding>
The list of Membership RBACRoleBindings.
Corresponds to the JSON property rbacrolebindings
3824 3825 3826 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3824 def rbacrolebindings @rbacrolebindings end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3829 3830 3831 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3829 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3836 3837 3838 3839 3840 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3836 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |