Class: Google::Apis::GkehubV1::ListMembershipRbacRoleBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipRbacRoleBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of Membership RBACRoleBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindingsmethod. -
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1::RbacRoleBinding>
The list of Membership RBACRoleBindings.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
constructor
A new instance of ListMembershipRbacRoleBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipRbacRoleBindingsResponse
Returns a new instance of ListMembershipRbacRoleBindingsResponse.
3706 3707 3708 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipRBACRoleBindings method. The value of an empty string means
that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3694 3695 3696 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3694 def next_page_token @next_page_token end |
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1::RbacRoleBinding>
The list of Membership RBACRoleBindings.
Corresponds to the JSON property rbacrolebindings
3699 3700 3701 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3699 def rbacrolebindings @rbacrolebindings end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3704 3705 3706 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3704 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3711 3712 3713 3714 3715 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3711 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings) @unreachable = args[:unreachable] if args.key?(:unreachable) end |