Class: Google::Apis::GkehubV1::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
3864 3865 3866 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3852 3853 3854 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3852 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
3857 3858 3859 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3857 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3862 3863 3864 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3862 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3869 3870 3871 3872 3873 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3869 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |