Class: Google::Apis::GkehubV1::ListMembershipsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Response message for the GkeHub.ListMemberships method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipsResponse

Returns a new instance of ListMembershipsResponse.



3863
3864
3865
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListMemberships method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3851
3852
3853
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3851

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1::Membership>

The list of matching Memberships. Corresponds to the JSON property resources



3856
3857
3858
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3856

def resources
  @resources
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3861
3862
3863
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3861

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3868
3869
3870
3871
3872
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3868

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end