Class: Google::Apis::GkehubV1::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
3739 3740 3741 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3727 3728 3729 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3727 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
3732 3733 3734 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3732 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3737 3738 3739 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3737 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3744 3745 3746 3747 3748 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3744 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |