Class: Google::Apis::GkehubV1::ListPermittedScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of permitted Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPermittedScopesResponse

Returns a new instance of ListPermittedScopesResponse.



3926
3927
3928
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3919

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1::Scope>

The list of permitted Scopes Corresponds to the JSON property scopes

Returns:



3924
3925
3926
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3924

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3931
3932
3933
3934
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3931

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end