Class: Google::Apis::GkehubV1::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListPermittedScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of permitted Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPermittedScopesResponse
constructor
A new instance of ListPermittedScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPermittedScopesResponse
Returns a new instance of ListPermittedScopesResponse.
3925 3926 3927 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListPermittedScopes
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3918 3919 3920 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3918 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of permitted Scopes
Corresponds to the JSON property scopes
3923 3924 3925 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3923 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3930 3931 3932 3933 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3930 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |