Class: Google::Apis::GkehubV1::ListPermittedScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of permitted Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPermittedScopesResponse

Returns a new instance of ListPermittedScopesResponse.



3923
3924
3925
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3916
3917
3918
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3916

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1::Scope>

The list of permitted Scopes Corresponds to the JSON property scopes

Returns:



3921
3922
3923
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3921

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3928
3929
3930
3931
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3928

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end