Class: Google::Apis::GkehubV1::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListPermittedScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of permitted Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPermittedScopesResponse
constructor
A new instance of ListPermittedScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPermittedScopesResponse
Returns a new instance of ListPermittedScopesResponse.
3838 3839 3840 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListPermittedScopes
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3831 3832 3833 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3831 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of permitted Scopes
Corresponds to the JSON property scopes
3836 3837 3838 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3836 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3843 3844 3845 3846 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3843 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |