Class: Google::Apis::GkehubV1::ListScopeNamespacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListScopeNamespacesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of fleet namespaces.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListNamespacesmethod. -
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1::Namespace>
The list of fleet namespaces Corresponds to the JSON property
scopeNamespaces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopeNamespacesResponse
constructor
A new instance of ListScopeNamespacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopeNamespacesResponse
Returns a new instance of ListScopeNamespacesResponse.
4011 4012 4013 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListNamespaces method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4004 4005 4006 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4004 def next_page_token @next_page_token end |
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1::Namespace>
The list of fleet namespaces
Corresponds to the JSON property scopeNamespaces
4009 4010 4011 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4009 def scope_namespaces @scope_namespaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4016 4017 4018 4019 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4016 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces) end |