Class: Google::Apis::GkehubV1::ListScopeNamespacesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of fleet namespaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeNamespacesResponse

Returns a new instance of ListScopeNamespacesResponse.



4004
4005
4006
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3997
3998
3999
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3997

def next_page_token
  @next_page_token
end

#scope_namespacesArray<Google::Apis::GkehubV1::Namespace>

The list of fleet namespaces Corresponds to the JSON property scopeNamespaces



4002
4003
4004
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4002

def scope_namespaces
  @scope_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4009
4010
4011
4012
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4009

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces)
end