Class: Google::Apis::GkehubV1::ListScopeNamespacesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListScopeNamespacesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of fleet namespaces.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListNamespacesmethod. -
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1::Namespace>
The list of fleet namespaces Corresponds to the JSON property
scopeNamespaces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopeNamespacesResponse
constructor
A new instance of ListScopeNamespacesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopeNamespacesResponse
Returns a new instance of ListScopeNamespacesResponse.
3995 3996 3997 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListNamespaces method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3988 3989 3990 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3988 def next_page_token @next_page_token end |
#scope_namespaces ⇒ Array<Google::Apis::GkehubV1::Namespace>
The list of fleet namespaces
Corresponds to the JSON property scopeNamespaces
3993 3994 3995 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3993 def scope_namespaces @scope_namespaces end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4000 4001 4002 4003 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4000 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces) end |