Class: Google::Apis::GkehubV1::ListScopeNamespacesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of fleet namespaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeNamespacesResponse

Returns a new instance of ListScopeNamespacesResponse.



3827
3828
3829
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3820
3821
3822
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3820

def next_page_token
  @next_page_token
end

#scope_namespacesArray<Google::Apis::GkehubV1::Namespace>

The list of fleet namespaces Corresponds to the JSON property scopeNamespaces



3825
3826
3827
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3825

def scope_namespaces
  @scope_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3832
3833
3834
3835
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3832

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces)
end