Class: Google::Apis::GkehubV1::ListScopeRbacRoleBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of Scope RBACRoleBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse

Returns a new instance of ListScopeRbacRoleBindingsResponse.



4030
4031
4032
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4023
4024
4025
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4023

def next_page_token
  @next_page_token
end

#rbacrolebindingsArray<Google::Apis::GkehubV1::RbacRoleBinding>

The list of Scope RBACRoleBindings. Corresponds to the JSON property rbacrolebindings



4028
4029
4030
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4028

def rbacrolebindings
  @rbacrolebindings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4035
4036
4037
4038
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4035

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings)
end