Class: Google::Apis::GkehubV1::ListScopeRbacRoleBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

List of Scope RBACRoleBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse

Returns a new instance of ListScopeRbacRoleBindingsResponse.



3854
3855
3856
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3847
3848
3849
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3847

def next_page_token
  @next_page_token
end

#rbacrolebindingsArray<Google::Apis::GkehubV1::RbacRoleBinding>

The list of Scope RBACRoleBindings. Corresponds to the JSON property rbacrolebindings



3852
3853
3854
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3852

def rbacrolebindings
  @rbacrolebindings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3859
3860
3861
3862
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3859

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings)
end