Class: Google::Apis::GkehubV1::ListScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopesResponse
constructor
A new instance of ListScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopesResponse
Returns a new instance of ListScopesResponse.
4048 4049 4050 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListScopes method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4041 4042 4043 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4041 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of Scopes
Corresponds to the JSON property scopes
4046 4047 4048 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4046 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4053 4054 4055 4056 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4053 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |