Class: Google::Apis::GkehubV1::ListScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ListScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
List of Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopesResponse
constructor
A new instance of ListScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopesResponse
Returns a new instance of ListScopesResponse.
3917 3918 3919 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListScopes method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3910 3911 3912 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3910 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1::Scope>
The list of Scopes
Corresponds to the JSON property scopes
3915 3916 3917 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3915 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3922 3923 3924 3925 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3922 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |