Class: Google::Apis::GkehubV1::Membership
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Membership
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Membership contains information about a member cluster.
Instance Attribute Summary collapse
-
#authority ⇒ Google::Apis::GkehubV1::Authority
Authority encodes how Google will recognize identities from this Membership.
-
#cluster_tier ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#endpoint ⇒ Google::Apis::GkehubV1::MembershipEndpoint
MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.
-
#external_id ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_connection_time ⇒ String
Output only.
-
#membership_type ⇒ String
Output only.
-
#monitoring_config ⇒ Google::Apis::GkehubV1::MonitoringConfig
MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::GkehubV1::MembershipState
MembershipState describes the state of a Membership resource.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Membership
constructor
A new instance of Membership.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Membership
Returns a new instance of Membership.
4224 4225 4226 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authority ⇒ Google::Apis::GkehubV1::Authority
Authority encodes how Google will recognize identities from this Membership.
See the workload identity documentation for more details: https://cloud.google.
com/kubernetes-engine/docs/how-to/workload-identity
Corresponds to the JSON property authority
4131 4132 4133 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4131 def @authority end |
#cluster_tier ⇒ String
Output only. The tier of the cluster.
Corresponds to the JSON property clusterTier
4136 4137 4138 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4136 def cluster_tier @cluster_tier end |
#create_time ⇒ String
Output only. When the Membership was created.
Corresponds to the JSON property createTime
4141 4142 4143 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4141 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the Membership was deleted.
Corresponds to the JSON property deleteTime
4146 4147 4148 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4146 def delete_time @delete_time end |
#description ⇒ String
Output only. Description of this membership, limited to 63 characters. Must
match the regex: a-zA-Z0-9* This field is present for legacy purposes.
Corresponds to the JSON property description
4152 4153 4154 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4152 def description @description end |
#endpoint ⇒ Google::Apis::GkehubV1::MembershipEndpoint
MembershipEndpoint contains information needed to contact a Kubernetes API,
endpoint and any additional Kubernetes metadata.
Corresponds to the JSON property endpoint
4158 4159 4160 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4158 def endpoint @endpoint end |
#external_id ⇒ String
Optional. An externally-generated and managed ID for this Membership. This ID
may be modified after creation, but this is not recommended. The ID must match
the regex: a-zA-Z0-9* If this Membership represents a Kubernetes cluster,
this value should be set to the UID of the kube-system namespace object.
Corresponds to the JSON property externalId
4166 4167 4168 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4166 def external_id @external_id end |
#labels ⇒ Hash<String,String>
Optional. Labels for this membership. These labels are not leveraged by multi-
cluster features, instead, we prefer cluster labels, which can be set on GKE
cluster or other cluster types.
Corresponds to the JSON property labels
4173 4174 4175 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4173 def labels @labels end |
#last_connection_time ⇒ String
Output only. For clusters using Connect, the timestamp of the most recent
connection established with Google Cloud. This time is updated every several
minutes, not continuously. For clusters that do not use GKE Connect, or that
have never connected successfully, this field will be unset.
Corresponds to the JSON property lastConnectionTime
4181 4182 4183 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4181 def last_connection_time @last_connection_time end |
#membership_type ⇒ String
Output only. The type of the membership.
Corresponds to the JSON property membershipType
4186 4187 4188 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4186 def membership_type @membership_type end |
#monitoring_config ⇒ Google::Apis::GkehubV1::MonitoringConfig
MonitoringConfig informs Fleet-based applications/services/UIs how the metrics
for the underlying cluster is reported to cloud monitoring services. It can be
set from empty to non-empty, but can't be mutated directly to prevent
accidentally breaking the constinousty of metrics.
Corresponds to the JSON property monitoringConfig
4194 4195 4196 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4194 def monitoring_config @monitoring_config end |
#name ⇒ String
Output only. The full, unique name of this Membership resource in the format
projects/*/locations/*/memberships/membership_id`, set during creation.
membership_idmust be a valid RFC 1123 compliant DNS label: 1. At most 63
characters in length 2. It must consist of lower case alphanumeric characters
or-3. It must start and end with an alphanumeric character Which can be
expressed as the regex:a-z0-9?, with a maximum length
of 63 characters.
Corresponds to the JSON propertyname`
4205 4206 4207 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4205 def name @name end |
#state ⇒ Google::Apis::GkehubV1::MembershipState
MembershipState describes the state of a Membership resource.
Corresponds to the JSON property state
4210 4211 4212 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4210 def state @state end |
#unique_id ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Membership resources. If a Membership resource is deleted and another
resource with the same name is created, it gets a different unique_id.
Corresponds to the JSON property uniqueId
4217 4218 4219 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4217 def unique_id @unique_id end |
#update_time ⇒ String
Output only. When the Membership was last updated.
Corresponds to the JSON property updateTime
4222 4223 4224 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4222 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4229 def update!(**args) @authority = args[:authority] if args.key?(:authority) @cluster_tier = args[:cluster_tier] if args.key?(:cluster_tier) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @endpoint = args[:endpoint] if args.key?(:endpoint) @external_id = args[:external_id] if args.key?(:external_id) @labels = args[:labels] if args.key?(:labels) @last_connection_time = args[:last_connection_time] if args.key?(:last_connection_time) @membership_type = args[:membership_type] if args.key?(:membership_type) @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |