Class: Google::Apis::GkehubV1::Membership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Membership contains information about a member cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



4077
4078
4079
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityGoogle::Apis::GkehubV1::Authority

Authority encodes how Google will recognize identities from this Membership. See the workload identity documentation for more details: https://cloud.google. com/kubernetes-engine/docs/how-to/workload-identity Corresponds to the JSON property authority



3984
3985
3986
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3984

def authority
  @authority
end

#cluster_tierString

Output only. The tier of the cluster. Corresponds to the JSON property clusterTier

Returns:

  • (String)


3989
3990
3991
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3989

def cluster_tier
  @cluster_tier
end

#create_timeString

Output only. When the Membership was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3994
3995
3996
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3994

def create_time
  @create_time
end

#delete_timeString

Output only. When the Membership was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/gkehub_v1/classes.rb', line 3999

def delete_time
  @delete_time
end

#descriptionString

Output only. Description of this membership, limited to 63 characters. Must match the regex: a-zA-Z0-9* This field is present for legacy purposes. Corresponds to the JSON property description

Returns:

  • (String)


4005
4006
4007
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4005

def description
  @description
end

#endpointGoogle::Apis::GkehubV1::MembershipEndpoint

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata. Corresponds to the JSON property endpoint



4011
4012
4013
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4011

def endpoint
  @endpoint
end

#external_idString

Optional. An externally-generated and managed ID for this Membership. This ID may be modified after creation, but this is not recommended. The ID must match the regex: a-zA-Z0-9* If this Membership represents a Kubernetes cluster, this value should be set to the UID of the kube-system namespace object. Corresponds to the JSON property externalId

Returns:

  • (String)


4019
4020
4021
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4019

def external_id
  @external_id
end

#labelsHash<String,String>

Optional. Labels for this membership. These labels are not leveraged by multi- cluster features, instead, we prefer cluster labels, which can be set on GKE cluster or other cluster types. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4026
4027
4028
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4026

def labels
  @labels
end

#last_connection_timeString

Output only. For clusters using Connect, the timestamp of the most recent connection established with Google Cloud. This time is updated every several minutes, not continuously. For clusters that do not use GKE Connect, or that have never connected successfully, this field will be unset. Corresponds to the JSON property lastConnectionTime

Returns:

  • (String)


4034
4035
4036
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4034

def last_connection_time
  @last_connection_time
end

#membership_typeString

Output only. The type of the membership. Corresponds to the JSON property membershipType

Returns:

  • (String)


4039
4040
4041
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4039

def membership_type
  @membership_type
end

#monitoring_configGoogle::Apis::GkehubV1::MonitoringConfig

MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services. It can be set from empty to non-empty, but can't be mutated directly to prevent accidentally breaking the constinousty of metrics. Corresponds to the JSON property monitoringConfig



4047
4048
4049
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4047

def monitoring_config
  @monitoring_config
end

#nameString

Output only. The full, unique name of this Membership resource in the format projects/*/locations/*/memberships/membership_id`, set during creation. membership_idmust be a valid RFC 1123 compliant DNS label: 1. At most 63 characters in length 2. It must consist of lower case alphanumeric characters or-3. It must start and end with an alphanumeric character Which can be expressed as the regex:a-z0-9?, with a maximum length of 63 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


4058
4059
4060
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4058

def name
  @name
end

#stateGoogle::Apis::GkehubV1::MembershipState

MembershipState describes the state of a Membership resource. Corresponds to the JSON property state



4063
4064
4065
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4063

def state
  @state
end

#unique_idString

Output only. Google-generated UUID for this resource. This is unique across all Membership resources. If a Membership resource is deleted and another resource with the same name is created, it gets a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4070
4071
4072
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4070

def unique_id
  @unique_id
end

#update_timeString

Output only. When the Membership was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4075
4076
4077
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4075

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4082
4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4082

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @cluster_tier = args[:cluster_tier] if args.key?(:cluster_tier)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @external_id = args[:external_id] if args.key?(:external_id)
  @labels = args[:labels] if args.key?(:labels)
  @last_connection_time = args[:last_connection_time] if args.key?(:last_connection_time)
  @membership_type = args[:membership_type] if args.key?(:membership_type)
  @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end