Class: Google::Apis::GkehubV1::MembershipEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipEndpoint

Returns a new instance of MembershipEndpoint.



4372
4373
4374
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_clusterGoogle::Apis::GkehubV1::ApplianceCluster

ApplianceCluster contains information specific to GDC Edge Appliance Clusters. Corresponds to the JSON property applianceCluster



4330
4331
4332
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4330

def appliance_cluster
  @appliance_cluster
end

#edge_clusterGoogle::Apis::GkehubV1::EdgeCluster

EdgeCluster contains information specific to Google Edge Clusters. Corresponds to the JSON property edgeCluster



4335
4336
4337
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4335

def edge_cluster
  @edge_cluster
end

#gke_clusterGoogle::Apis::GkehubV1::GkeCluster

GkeCluster contains information specific to GKE clusters. Corresponds to the JSON property gkeCluster



4340
4341
4342
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4340

def gke_cluster
  @gke_cluster
end

#google_managedBoolean Also known as: google_managed?

Output only. Whether the lifecycle of this membership is managed by a google cluster platform service. Corresponds to the JSON property googleManaged

Returns:

  • (Boolean)


4346
4347
4348
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4346

def google_managed
  @google_managed
end

#kubernetes_metadataGoogle::Apis::GkehubV1::KubernetesMetadata

KubernetesMetadata provides informational metadata for Memberships representing Kubernetes clusters. Corresponds to the JSON property kubernetesMetadata



4353
4354
4355
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4353

def 
  @kubernetes_metadata
end

#kubernetes_resourceGoogle::Apis::GkehubV1::KubernetesResource

KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster. Corresponds to the JSON property kubernetesResource



4360
4361
4362
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4360

def kubernetes_resource
  @kubernetes_resource
end

#multi_cloud_clusterGoogle::Apis::GkehubV1::MultiCloudCluster

MultiCloudCluster contains information specific to GKE Multi-Cloud clusters. Corresponds to the JSON property multiCloudCluster



4365
4366
4367
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4365

def multi_cloud_cluster
  @multi_cloud_cluster
end

#on_prem_clusterGoogle::Apis::GkehubV1::OnPremCluster

OnPremCluster contains information specific to GKE On-Prem clusters. Corresponds to the JSON property onPremCluster



4370
4371
4372
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4370

def on_prem_cluster
  @on_prem_cluster
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4377

def update!(**args)
  @appliance_cluster = args[:appliance_cluster] if args.key?(:appliance_cluster)
  @edge_cluster = args[:edge_cluster] if args.key?(:edge_cluster)
  @gke_cluster = args[:gke_cluster] if args.key?(:gke_cluster)
  @google_managed = args[:google_managed] if args.key?(:google_managed)
  @kubernetes_metadata = args[:kubernetes_metadata] if args.key?(:kubernetes_metadata)
  @kubernetes_resource = args[:kubernetes_resource] if args.key?(:kubernetes_resource)
  @multi_cloud_cluster = args[:multi_cloud_cluster] if args.key?(:multi_cloud_cluster)
  @on_prem_cluster = args[:on_prem_cluster] if args.key?(:on_prem_cluster)
end