Class: Google::Apis::GkehubV1::MembershipFeatureSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::MembershipFeatureSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
MembershipFeatureSpec contains configuration information for a single Membership.
Instance Attribute Summary collapse
-
#configmanagement ⇒ Google::Apis::GkehubV1::ConfigManagementMembershipSpec
Anthos Config Management: Configuration for a single cluster.
-
#fleetobservability ⇒ Google::Apis::GkehubV1::FleetObservabilityMembershipSpec
FleetObservability: The membership-specific input for FleetObservability feature.
-
#identityservice ⇒ Google::Apis::GkehubV1::IdentityServiceMembershipSpec
Anthos Identity Service: Configuration for a single Membership.
-
#mesh ⇒ Google::Apis::GkehubV1::ServiceMeshMembershipSpec
Service Mesh: Spec for a single Membership for the servicemesh feature Corresponds to the JSON property
mesh. -
#origin ⇒ Google::Apis::GkehubV1::Origin
Origin defines where this MembershipFeatureSpec originated from.
-
#policycontroller ⇒ Google::Apis::GkehubV1::PolicyControllerMembershipSpec
Policy Controller: Configuration for a single cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipFeatureSpec
constructor
A new instance of MembershipFeatureSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipFeatureSpec
Returns a new instance of MembershipFeatureSpec.
4290 4291 4292 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configmanagement ⇒ Google::Apis::GkehubV1::ConfigManagementMembershipSpec
Anthos Config Management: Configuration for a single cluster. Intended to
parallel the ConfigManagement CR.
Corresponds to the JSON property configmanagement
4261 4262 4263 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4261 def configmanagement @configmanagement end |
#fleetobservability ⇒ Google::Apis::GkehubV1::FleetObservabilityMembershipSpec
FleetObservability: The membership-specific input for FleetObservability
feature.
Corresponds to the JSON property fleetobservability
4267 4268 4269 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4267 def fleetobservability @fleetobservability end |
#identityservice ⇒ Google::Apis::GkehubV1::IdentityServiceMembershipSpec
Anthos Identity Service: Configuration for a single Membership.
Corresponds to the JSON property identityservice
4272 4273 4274 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4272 def identityservice @identityservice end |
#mesh ⇒ Google::Apis::GkehubV1::ServiceMeshMembershipSpec
Service Mesh: Spec for a single Membership for the servicemesh feature
Corresponds to the JSON property mesh
4277 4278 4279 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4277 def mesh @mesh end |
#origin ⇒ Google::Apis::GkehubV1::Origin
Origin defines where this MembershipFeatureSpec originated from.
Corresponds to the JSON property origin
4282 4283 4284 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4282 def origin @origin end |
#policycontroller ⇒ Google::Apis::GkehubV1::PolicyControllerMembershipSpec
Policy Controller: Configuration for a single cluster. Intended to
parallel the PolicyController CR.
Corresponds to the JSON property policycontroller
4288 4289 4290 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4288 def policycontroller @policycontroller end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4295 4296 4297 4298 4299 4300 4301 4302 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4295 def update!(**args) @configmanagement = args[:configmanagement] if args.key?(:configmanagement) @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability) @identityservice = args[:identityservice] if args.key?(:identityservice) @mesh = args[:mesh] if args.key?(:mesh) @origin = args[:origin] if args.key?(:origin) @policycontroller = args[:policycontroller] if args.key?(:policycontroller) end |