Class: Google::Apis::GkehubV1::MembershipFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

MembershipFeatureState contains Feature status information for a single Membership.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipFeatureState

Returns a new instance of MembershipFeatureState.



4491
4492
4493
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV1::AppDevExperienceFeatureState

State for App Dev Exp Feature. Corresponds to the JSON property appdevexperience



4444
4445
4446
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4444

def appdevexperience
  @appdevexperience
end

#clusterupgradeGoogle::Apis::GkehubV1::ClusterUpgradeMembershipState

Per-membership state for this feature. Corresponds to the JSON property clusterupgrade



4449
4450
4451
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4449

def clusterupgrade
  @clusterupgrade
end

#configmanagementGoogle::Apis::GkehubV1::ConfigManagementMembershipState

Anthos Config Management: State for a single cluster. Corresponds to the JSON property configmanagement



4454
4455
4456
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4454

def configmanagement
  @configmanagement
end

#fleetobservabilityGoogle::Apis::GkehubV1::FleetObservabilityMembershipState

FleetObservability: Membership-specific Feature state for fleetobservability. Corresponds to the JSON property fleetobservability



4460
4461
4462
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4460

def fleetobservability
  @fleetobservability
end

#identityserviceGoogle::Apis::GkehubV1::IdentityServiceMembershipState

Anthos Identity Service: State for a single Membership. Corresponds to the JSON property identityservice



4465
4466
4467
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4465

def identityservice
  @identityservice
end

#policycontrollerGoogle::Apis::GkehubV1::PolicyControllerMembershipState

Policy Controller: State for a single cluster. Corresponds to the JSON property policycontroller



4470
4471
4472
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4470

def policycontroller
  @policycontroller
end

#servicemeshGoogle::Apis::GkehubV1::ServiceMeshMembershipState

Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller. Corresponds to the JSON property servicemesh



4476
4477
4478
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4476

def servicemesh
  @servicemesh
end

#stateGoogle::Apis::GkehubV1::FeatureState

FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context. Corresponds to the JSON property state



4483
4484
4485
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4483

def state
  @state
end

#workloadidentityGoogle::Apis::GkehubV1::WorkloadIdentityMembershipState

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature. Corresponds to the JSON property workloadidentity



4489
4490
4491
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4489

def workloadidentity
  @workloadidentity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4496
4497
4498
4499
4500
4501
4502
4503
4504
4505
4506
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4496

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
  @servicemesh = args[:servicemesh] if args.key?(:servicemesh)
  @state = args[:state] if args.key?(:state)
  @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity)
end