Class: Google::Apis::GkehubV1::MembershipFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::MembershipFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
MembershipFeatureState contains Feature status information for a single Membership.
Instance Attribute Summary collapse
-
#appdevexperience ⇒ Google::Apis::GkehubV1::AppDevExperienceFeatureState
State for App Dev Exp Feature.
-
#clusterupgrade ⇒ Google::Apis::GkehubV1::ClusterUpgradeMembershipState
Per-membership state for this feature.
-
#configmanagement ⇒ Google::Apis::GkehubV1::ConfigManagementMembershipState
Anthos Config Management: State for a single cluster.
-
#fleetobservability ⇒ Google::Apis::GkehubV1::FleetObservabilityMembershipState
FleetObservability: Membership-specific Feature state for fleetobservability.
-
#identityservice ⇒ Google::Apis::GkehubV1::IdentityServiceMembershipState
Anthos Identity Service: State for a single Membership.
-
#policycontroller ⇒ Google::Apis::GkehubV1::PolicyControllerMembershipState
Policy Controller: State for a single cluster.
-
#servicemesh ⇒ Google::Apis::GkehubV1::ServiceMeshMembershipState
Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller.
-
#state ⇒ Google::Apis::GkehubV1::FeatureState
FeatureState describes the high-level state of a Feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipFeatureState
constructor
A new instance of MembershipFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipFeatureState
Returns a new instance of MembershipFeatureState.
4317 4318 4319 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appdevexperience ⇒ Google::Apis::GkehubV1::AppDevExperienceFeatureState
State for App Dev Exp Feature.
Corresponds to the JSON property appdevexperience
4276 4277 4278 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4276 def appdevexperience @appdevexperience end |
#clusterupgrade ⇒ Google::Apis::GkehubV1::ClusterUpgradeMembershipState
Per-membership state for this feature.
Corresponds to the JSON property clusterupgrade
4281 4282 4283 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4281 def clusterupgrade @clusterupgrade end |
#configmanagement ⇒ Google::Apis::GkehubV1::ConfigManagementMembershipState
Anthos Config Management: State for a single cluster.
Corresponds to the JSON property configmanagement
4286 4287 4288 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4286 def configmanagement @configmanagement end |
#fleetobservability ⇒ Google::Apis::GkehubV1::FleetObservabilityMembershipState
FleetObservability: Membership-specific Feature state for
fleetobservability.
Corresponds to the JSON property fleetobservability
4292 4293 4294 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4292 def fleetobservability @fleetobservability end |
#identityservice ⇒ Google::Apis::GkehubV1::IdentityServiceMembershipState
Anthos Identity Service: State for a single Membership.
Corresponds to the JSON property identityservice
4297 4298 4299 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4297 def identityservice @identityservice end |
#policycontroller ⇒ Google::Apis::GkehubV1::PolicyControllerMembershipState
Policy Controller: State for a single cluster.
Corresponds to the JSON property policycontroller
4302 4303 4304 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4302 def policycontroller @policycontroller end |
#servicemesh ⇒ Google::Apis::GkehubV1::ServiceMeshMembershipState
Service Mesh: State for a single Membership, as analyzed by the Service
Mesh Hub Controller.
Corresponds to the JSON property servicemesh
4308 4309 4310 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4308 def servicemesh @servicemesh end |
#state ⇒ Google::Apis::GkehubV1::FeatureState
FeatureState describes the high-level state of a Feature. It may be used to
describe a Feature's state at the environ-level, or per-membershop, depending
on the context.
Corresponds to the JSON property state
4315 4316 4317 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4315 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4322 def update!(**args) @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience) @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade) @configmanagement = args[:configmanagement] if args.key?(:configmanagement) @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability) @identityservice = args[:identityservice] if args.key?(:identityservice) @policycontroller = args[:policycontroller] if args.key?(:policycontroller) @servicemesh = args[:servicemesh] if args.key?(:servicemesh) @state = args[:state] if args.key?(:state) end |