Class: Google::Apis::GkehubV1::MonitoringConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::MonitoringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services. It can be set from empty to non-empty, but can't be mutated directly to prevent accidentally breaking the constinousty of metrics.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Optional.
-
#cluster_hash ⇒ String
Optional.
-
#kubernetes_metrics_prefix ⇒ String
Optional.
-
#location ⇒ String
Optional.
-
#project_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonitoringConfig
constructor
A new instance of MonitoringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonitoringConfig
Returns a new instance of MonitoringConfig.
4391 4392 4393 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Optional. Cluster name used to report metrics. For Anthos on VMWare/Baremetal/
MultiCloud clusters, it would be in format cluster_type/cluster_name, e.g.,
"awsClusters/cluster_1".
Corresponds to the JSON property cluster
4365 4366 4367 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4365 def cluster @cluster end |
#cluster_hash ⇒ String
Optional. For GKE and Multicloud clusters, this is the UUID of the cluster
resource. For VMWare and Baremetal clusters, this is the kube-system UID.
Corresponds to the JSON property clusterHash
4371 4372 4373 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4371 def cluster_hash @cluster_hash end |
#kubernetes_metrics_prefix ⇒ String
Optional. Kubernetes system metrics, if available, are written to this prefix.
This defaults to kubernetes.io for GKE, and kubernetes.io/anthos for Anthos
eventually. Noted: Anthos MultiCloud will have kubernetes.io prefix today but
will migration to be under kubernetes.io/anthos.
Corresponds to the JSON property kubernetesMetricsPrefix
4379 4380 4381 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4379 def kubernetes_metrics_prefix @kubernetes_metrics_prefix end |
#location ⇒ String
Optional. Location used to report Metrics
Corresponds to the JSON property location
4384 4385 4386 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4384 def location @location end |
#project_id ⇒ String
Optional. Project used to report Metrics
Corresponds to the JSON property projectId
4389 4390 4391 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4389 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4396 4397 4398 4399 4400 4401 4402 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4396 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @cluster_hash = args[:cluster_hash] if args.key?(:cluster_hash) @kubernetes_metrics_prefix = args[:kubernetes_metrics_prefix] if args.key?(:kubernetes_metrics_prefix) @location = args[:location] if args.key?(:location) @project_id = args[:project_id] if args.key?(:project_id) end |