Class: Google::Apis::GkehubV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
4699 4700 4701 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
4663 4664 4665 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4663 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelRequested
4671 4672 4673 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4671 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
4677 4678 4679 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4677 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
4682 4683 4684 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4682 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
4687 4688 4689 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4687 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
4692 4693 4694 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4692 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
4697 4698 4699 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4697 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4704 4705 4706 4707 4708 4709 4710 4711 4712 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4704 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |