Class: Google::Apis::GkehubV1::OperationalState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::OperationalState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Operational state of the Rollout Sequence.
Instance Attribute Summary collapse
-
#reasons ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#state_change_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationalState
constructor
A new instance of OperationalState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationalState
Returns a new instance of OperationalState.
4919 4920 4921 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reasons ⇒ Array<String>
Output only. Reasons for the Rollout Sequence state.
Corresponds to the JSON property reasons
4906 4907 4908 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4906 def reasons @reasons end |
#state ⇒ String
Output only. State of the Rollout Sequence.
Corresponds to the JSON property state
4911 4912 4913 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4911 def state @state end |
#state_change_time ⇒ String
Output only. The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Corresponds to the JSON property stateChangeTime
4917 4918 4919 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4917 def state_change_time @state_change_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4924 4925 4926 4927 4928 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4924 def update!(**args) @reasons = args[:reasons] if args.key?(:reasons) @state = args[:state] if args.key?(:state) @state_change_time = args[:state_change_time] if args.key?(:state_change_time) end |