Class: Google::Apis::GkehubV1::OperationalState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Operational state of the Rollout Sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationalState

Returns a new instance of OperationalState.



4916
4917
4918
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonsArray<String>

Output only. Reasons for the Rollout Sequence state. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


4903
4904
4905
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4903

def reasons
  @reasons
end

#stateString

Output only. State of the Rollout Sequence. Corresponds to the JSON property state

Returns:

  • (String)


4908
4909
4910
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4908

def state
  @state
end

#state_change_timeString

Output only. The timestamp at which the operational state was last changed. Used to track how long it has been in the current state. Corresponds to the JSON property stateChangeTime

Returns:

  • (String)


4914
4915
4916
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4914

def state_change_time
  @state_change_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4921
4922
4923
4924
4925
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4921

def update!(**args)
  @reasons = args[:reasons] if args.key?(:reasons)
  @state = args[:state] if args.key?(:state)
  @state_change_time = args[:state_change_time] if args.key?(:state_change_time)
end