Class: Google::Apis::GkehubV1::OperationalState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Operational state of the Rollout Sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationalState

Returns a new instance of OperationalState.



4910
4911
4912
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonsArray<String>

Output only. Reasons for the Rollout Sequence state. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


4897
4898
4899
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4897

def reasons
  @reasons
end

#stateString

Output only. State of the Rollout Sequence. Corresponds to the JSON property state

Returns:

  • (String)


4902
4903
4904
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4902

def state
  @state
end

#state_change_timeString

Output only. The timestamp at which the operational state was last changed. Used to track how long it has been in the current state. Corresponds to the JSON property stateChangeTime

Returns:

  • (String)


4908
4909
4910
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4908

def state_change_time
  @state_change_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4915
4916
4917
4918
4919
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4915

def update!(**args)
  @reasons = args[:reasons] if args.key?(:reasons)
  @state = args[:state] if args.key?(:state)
  @state_change_time = args[:state_change_time] if args.key?(:state_change_time)
end