Class: Google::Apis::GkehubV1::PolicyControllerMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Policy Controller: State for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerMembershipState

Returns a new instance of PolicyControllerMembershipState.



5003
5004
5005
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_statesHash<String,Google::Apis::GkehubV1::PolicyControllerOnClusterState>

Currently these include (also serving as map keys): 1. "admission" 2. "audit"

  1. "mutation" Corresponds to the JSON property componentStates


4990
4991
4992
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4990

def component_states
  @component_states
end

#policy_content_stateGoogle::Apis::GkehubV1::PolicyControllerPolicyContentState

The state of the policy controller policy content Corresponds to the JSON property policyContentState



4995
4996
4997
# File 'lib/google/apis/gkehub_v1/classes.rb', line 4995

def policy_content_state
  @policy_content_state
end

#stateString

The overall Policy Controller lifecycle state observed by the Hub Feature controller. Corresponds to the JSON property state

Returns:

  • (String)


5001
5002
5003
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5001

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5008
5009
5010
5011
5012
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5008

def update!(**args)
  @component_states = args[:component_states] if args.key?(:component_states)
  @policy_content_state = args[:policy_content_state] if args.key?(:policy_content_state)
  @state = args[:state] if args.key?(:state)
end