Class: Google::Apis::GkehubV1::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Rollout contains the Rollout metadata and configuration. Next ID: 28
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#intent ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1::RolloutMembershipState>
Output only.
-
#name ⇒ String
Identifier.
-
#rollout_sequence ⇒ String
Optional.
-
#stages ⇒ Array<Google::Apis::GkehubV1::RolloutStage>
Output only.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#state_reason_type ⇒ String
Output only.
-
#trigger ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_upgrade ⇒ Google::Apis::GkehubV1::VersionUpgrade
Config for version upgrade of clusters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
5864 5865 5866 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completeTime
5769 5770 5771 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5769 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout was created.
Corresponds to the JSON property createTime
5774 5775 5776 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5774 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout was deleted.
Corresponds to the JSON property deleteTime
5779 5780 5781 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5779 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout.
Corresponds to the JSON property displayName
5784 5785 5786 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5784 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Ex. abc1234
Corresponds to the JSON property etag
5789 5790 5791 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5789 def etag @etag end |
#intent ⇒ String
Output only. The intent of the rollout.
Corresponds to the JSON property intent
5794 5795 5796 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5794 def intent @intent end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout.
Corresponds to the JSON property labels
5799 5800 5801 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5799 def labels @labels end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1::RolloutMembershipState>
Output only. States of upgrading control plane or node pool targets of a
single cluster (GKE Hub membership) that's part of this Rollout. The key is
the membership name of the cluster. The value is the state of the cluster.
Corresponds to the JSON property membershipStates
5806 5807 5808 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5806 def membership_states @membership_states end |
#name ⇒ String
Identifier. The full, unique resource name of this Rollout in the format of
projects/project/locations/global/rollouts/rollout`.
Corresponds to the JSON propertyname`
5812 5813 5814 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5812 def name @name end |
#rollout_sequence ⇒ String
Optional. Immutable. The full, unique resource name of the rollout sequence
that initiatied this Rollout. In the format of projects/project/locations/
global/rolloutSequences/rollout_sequence`.
Corresponds to the JSON propertyrolloutSequence`
5819 5820 5821 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5819 def rollout_sequence @rollout_sequence end |
#stages ⇒ Array<Google::Apis::GkehubV1::RolloutStage>
Output only. The stages of the Rollout.
Corresponds to the JSON property stages
5824 5825 5826 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5824 def stages @stages end |
#state ⇒ String
Output only. State specifies various states of the Rollout.
Corresponds to the JSON property state
5829 5830 5831 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5829 def state @state end |
#state_reason ⇒ String
Output only. A human-readable description explaining the reason for the
current state.
Corresponds to the JSON property stateReason
5835 5836 5837 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5835 def state_reason @state_reason end |
#state_reason_type ⇒ String
Output only. StateReasonType specifies the reason type of the Rollout state.
Corresponds to the JSON property stateReasonType
5840 5841 5842 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5840 def state_reason_type @state_reason_type end |
#trigger ⇒ String
Output only. The trigger of the rollout.
Corresponds to the JSON property trigger
5845 5846 5847 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5845 def trigger @trigger end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout resources. If a Rollout resource is deleted and another resource
with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
5852 5853 5854 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5852 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout was last updated.
Corresponds to the JSON property updateTime
5857 5858 5859 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5857 def update_time @update_time end |
#version_upgrade ⇒ Google::Apis::GkehubV1::VersionUpgrade
Config for version upgrade of clusters.
Corresponds to the JSON property versionUpgrade
5862 5863 5864 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5862 def version_upgrade @version_upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 5888 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5869 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @intent = args[:intent] if args.key?(:intent) @labels = args[:labels] if args.key?(:labels) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type) @trigger = args[:trigger] if args.key?(:trigger) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade) end |