Class: Google::Apis::GkehubV1::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Rollout contains the Rollout metadata and configuration. Next ID: 28

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



5863
5864
5865
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


5768
5769
5770
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5768

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5773
5774
5775
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5773

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5778
5779
5780
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5778

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout. Corresponds to the JSON property displayName

Returns:

  • (String)


5783
5784
5785
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5783

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


5788
5789
5790
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5788

def etag
  @etag
end

#intentString

Output only. The intent of the rollout. Corresponds to the JSON property intent

Returns:

  • (String)


5793
5794
5795
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5793

def intent
  @intent
end

#labelsHash<String,String>

Optional. Labels for this Rollout. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5798
5799
5800
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5798

def labels
  @labels
end

#membership_statesHash<String,Google::Apis::GkehubV1::RolloutMembershipState>

Output only. States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout. The key is the membership name of the cluster. The value is the state of the cluster. Corresponds to the JSON property membershipStates



5805
5806
5807
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5805

def membership_states
  @membership_states
end

#nameString

Identifier. The full, unique resource name of this Rollout in the format of projects/project/locations/global/rollouts/rollout`. Corresponds to the JSON propertyname`

Returns:

  • (String)


5811
5812
5813
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5811

def name
  @name
end

#rollout_sequenceString

Optional. Immutable. The full, unique resource name of the rollout sequence that initiatied this Rollout. In the format of projects/project/locations/ global/rolloutSequences/rollout_sequence`. Corresponds to the JSON propertyrolloutSequence`

Returns:

  • (String)


5818
5819
5820
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5818

def rollout_sequence
  @rollout_sequence
end

#stagesArray<Google::Apis::GkehubV1::RolloutStage>

Output only. The stages of the Rollout. Corresponds to the JSON property stages



5823
5824
5825
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5823

def stages
  @stages
end

#stateString

Output only. State specifies various states of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


5828
5829
5830
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5828

def state
  @state
end

#state_reasonString

Output only. A human-readable description explaining the reason for the current state. Corresponds to the JSON property stateReason

Returns:

  • (String)


5834
5835
5836
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5834

def state_reason
  @state_reason
end

#state_reason_typeString

Output only. StateReasonType specifies the reason type of the Rollout state. Corresponds to the JSON property stateReasonType

Returns:

  • (String)


5839
5840
5841
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5839

def state_reason_type
  @state_reason_type
end

#triggerString

Output only. The trigger of the rollout. Corresponds to the JSON property trigger

Returns:

  • (String)


5844
5845
5846
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5844

def trigger
  @trigger
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout resources. If a Rollout resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5851
5852
5853
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5851

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5856
5857
5858
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5856

def update_time
  @update_time
end

#version_upgradeGoogle::Apis::GkehubV1::VersionUpgrade

Config for version upgrade of clusters. Corresponds to the JSON property versionUpgrade



5861
5862
5863
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5861

def version_upgrade
  @version_upgrade
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
5880
5881
5882
5883
5884
5885
5886
5887
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5868

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @intent = args[:intent] if args.key?(:intent)
  @labels = args[:labels] if args.key?(:labels)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence)
  @stages = args[:stages] if args.key?(:stages)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type)
  @trigger = args[:trigger] if args.key?(:trigger)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade)
end