Class: Google::Apis::GkehubV1::Rollout

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Rollout contains the Rollout metadata and configuration. Next ID: 28

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



5855
5856
5857
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#complete_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


5760
5761
5762
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5760

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp at which the Rollout was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5765
5766
5767
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5765

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5770
5771
5772
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5770

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout. Corresponds to the JSON property displayName

Returns:

  • (String)


5775
5776
5777
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5775

def display_name
  @display_name
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


5780
5781
5782
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5780

def etag
  @etag
end

#intentString

Output only. The intent of the rollout. Corresponds to the JSON property intent

Returns:

  • (String)


5785
5786
5787
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5785

def intent
  @intent
end

#labelsHash<String,String>

Optional. Labels for this Rollout. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5790
5791
5792
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5790

def labels
  @labels
end

#membership_statesHash<String,Google::Apis::GkehubV1::RolloutMembershipState>

Output only. States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout. The key is the membership name of the cluster. The value is the state of the cluster. Corresponds to the JSON property membershipStates



5797
5798
5799
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5797

def membership_states
  @membership_states
end

#nameString

Identifier. The full, unique resource name of this Rollout in the format of projects/project/locations/global/rollouts/rollout`. Corresponds to the JSON propertyname`

Returns:

  • (String)


5803
5804
5805
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5803

def name
  @name
end

#rollout_sequenceString

Optional. Immutable. The full, unique resource name of the rollout sequence that initiatied this Rollout. In the format of projects/project/locations/ global/rolloutSequences/rollout_sequence`. Corresponds to the JSON propertyrolloutSequence`

Returns:

  • (String)


5810
5811
5812
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5810

def rollout_sequence
  @rollout_sequence
end

#stagesArray<Google::Apis::GkehubV1::RolloutStage>

Output only. The stages of the Rollout. Corresponds to the JSON property stages



5815
5816
5817
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5815

def stages
  @stages
end

#stateString

Output only. State specifies various states of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


5820
5821
5822
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5820

def state
  @state
end

#state_reasonString

Output only. A human-readable description explaining the reason for the current state. Corresponds to the JSON property stateReason

Returns:

  • (String)


5826
5827
5828
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5826

def state_reason
  @state_reason
end

#state_reason_typeString

Output only. StateReasonType specifies the reason type of the Rollout state. Corresponds to the JSON property stateReasonType

Returns:

  • (String)


5831
5832
5833
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5831

def state_reason_type
  @state_reason_type
end

#triggerString

Output only. The trigger of the rollout. Corresponds to the JSON property trigger

Returns:

  • (String)


5836
5837
5838
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5836

def trigger
  @trigger
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout resources. If a Rollout resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5843
5844
5845
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5843

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5848
5849
5850
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5848

def update_time
  @update_time
end

#version_upgradeGoogle::Apis::GkehubV1::VersionUpgrade

Config for version upgrade of clusters. Corresponds to the JSON property versionUpgrade



5853
5854
5855
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5853

def version_upgrade
  @version_upgrade
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5860
5861
5862
5863
5864
5865
5866
5867
5868
5869
5870
5871
5872
5873
5874
5875
5876
5877
5878
5879
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5860

def update!(**args)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @intent = args[:intent] if args.key?(:intent)
  @labels = args[:labels] if args.key?(:labels)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence)
  @stages = args[:stages] if args.key?(:stages)
  @state = args[:state] if args.key?(:state)
  @state_reason = args[:state_reason] if args.key?(:state_reason)
  @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type)
  @trigger = args[:trigger] if args.key?(:trigger)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade)
end