Class: Google::Apis::GkehubV1::RolloutMembershipState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::RolloutMembershipState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Metadata about single cluster (GKE Hub membership) that's part of this Rollout.
Instance Attribute Summary collapse
-
#last_update_time ⇒ String
Optional.
-
#stage_assignment ⇒ Fixnum
Output only.
-
#targets ⇒ Array<Google::Apis::GkehubV1::RolloutTarget>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutMembershipState
constructor
A new instance of RolloutMembershipState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutMembershipState
Returns a new instance of RolloutMembershipState.
5923 5924 5925 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_update_time ⇒ String
Optional. Output only. The time this status and any related Rollout-specific
details for the membership were updated.
Corresponds to the JSON property lastUpdateTime
5909 5910 5911 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5909 def last_update_time @last_update_time end |
#stage_assignment ⇒ Fixnum
Output only. The stage assignment of this cluster in this rollout.
Corresponds to the JSON property stageAssignment
5914 5915 5916 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5914 def stage_assignment @stage_assignment end |
#targets ⇒ Array<Google::Apis::GkehubV1::RolloutTarget>
Output only. The targets of the rollout - clusters or node pools that are
being upgraded. All targets belongs to the same cluster, identified by the
membership name (key of membership_states map).
Corresponds to the JSON property targets
5921 5922 5923 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5921 def targets @targets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5928 5929 5930 5931 5932 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5928 def update!(**args) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @stage_assignment = args[:stage_assignment] if args.key?(:stage_assignment) @targets = args[:targets] if args.key?(:targets) end |