Class: Google::Apis::GkehubV1::RolloutSequence
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::RolloutSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
RolloutSequence defines the desired order of upgrades. Next ID: 20
Instance Attribute Summary collapse
-
#auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#computed_release_channel ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#etag ⇒ String
Output only.
-
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_qualified_control_plane_version ⇒ String
Output only.
-
#last_qualified_node_version ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#operational_state ⇒ Google::Apis::GkehubV1::OperationalState
Operational state of the Rollout Sequence.
-
#stages ⇒ Array<Google::Apis::GkehubV1::Stage>
Required.
-
#target_control_plane_version ⇒ String
Output only.
-
#target_node_version ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequence
constructor
A new instance of RolloutSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequence
Returns a new instance of RolloutSequence.
6038 6039 6040 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property autoUpgradeConfig
5948 5949 5950 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5948 def auto_upgrade_config @auto_upgrade_config end |
#computed_release_channel ⇒ String
Output only. The computed release channel used for the Rollout Sequence.
Corresponds to the JSON property computedReleaseChannel
5953 5954 5955 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5953 def computed_release_channel @computed_release_channel end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was created.
Corresponds to the JSON property createTime
5958 5959 5960 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5958 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout Sequence was deleted.
Corresponds to the JSON property deleteTime
5963 5964 5965 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5963 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout Sequence.
Corresponds to the JSON property displayName
5968 5969 5970 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5968 def display_name @display_name end |
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property effectiveAutoUpgradeConfig
5973 5974 5975 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5973 def effective_auto_upgrade_config @effective_auto_upgrade_config end |
#etag ⇒ String
Output only. etag of the Rollout Sequence Ex. abc1234
Corresponds to the JSON property etag
5978 5979 5980 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5978 def etag @etag end |
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
Corresponds to the JSON property ignoredClustersSelector
5983 5984 5985 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5983 def ignored_clusters_selector @ignored_clusters_selector end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout Sequence.
Corresponds to the JSON property labels
5988 5989 5990 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5988 def labels @labels end |
#last_qualified_control_plane_version ⇒ String
Output only. The last qualified control plane version.
Corresponds to the JSON property lastQualifiedControlPlaneVersion
5993 5994 5995 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5993 def last_qualified_control_plane_version @last_qualified_control_plane_version end |
#last_qualified_node_version ⇒ String
Output only. The last qualified node version.
Corresponds to the JSON property lastQualifiedNodeVersion
5998 5999 6000 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5998 def last_qualified_node_version @last_qualified_node_version end |
#name ⇒ String
Identifier. Name of the rollout sequence in the format of: projects/
PROJECT_ID/locations/global/rolloutSequences/NAME
Corresponds to the JSON property name
6004 6005 6006 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6004 def name @name end |
#operational_state ⇒ Google::Apis::GkehubV1::OperationalState
Operational state of the Rollout Sequence.
Corresponds to the JSON property operationalState
6009 6010 6011 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6009 def operational_state @operational_state end |
#stages ⇒ Array<Google::Apis::GkehubV1::Stage>
Required. Ordered list of stages that constitutes this Rollout.
Corresponds to the JSON property stages
6014 6015 6016 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6014 def stages @stages end |
#target_control_plane_version ⇒ String
Output only. The target control plane version of the Rollout Sequence.
Corresponds to the JSON property targetControlPlaneVersion
6019 6020 6021 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6019 def target_control_plane_version @target_control_plane_version end |
#target_node_version ⇒ String
Output only. The target node version of the Rollout Sequence.
Corresponds to the JSON property targetNodeVersion
6024 6025 6026 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6024 def target_node_version @target_node_version end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout Sequence resources. If a Rollout Sequence resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6031 6032 6033 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6031 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was last updated.
Corresponds to the JSON property updateTime
6036 6037 6038 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6036 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 6059 6060 6061 6062 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6043 def update!(**args) @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config) @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config) @etag = args[:etag] if args.key?(:etag) @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector) @labels = args[:labels] if args.key?(:labels) @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version) @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version) @name = args[:name] if args.key?(:name) @operational_state = args[:operational_state] if args.key?(:operational_state) @stages = args[:stages] if args.key?(:stages) @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version) @target_node_version = args[:target_node_version] if args.key?(:target_node_version) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |