Class: Google::Apis::GkehubV1::RolloutSequence
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::RolloutSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
RolloutSequence defines the desired order of upgrades. Next ID: 20
Instance Attribute Summary collapse
-
#auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#computed_release_channel ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#etag ⇒ String
Output only.
-
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_qualified_control_plane_version ⇒ String
Output only.
-
#last_qualified_node_version ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#operational_state ⇒ Google::Apis::GkehubV1::OperationalState
Operational state of the Rollout Sequence.
-
#stages ⇒ Array<Google::Apis::GkehubV1::Stage>
Required.
-
#target_control_plane_version ⇒ String
Output only.
-
#target_node_version ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequence
constructor
A new instance of RolloutSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequence
Returns a new instance of RolloutSequence.
6032 6033 6034 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property autoUpgradeConfig
5942 5943 5944 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5942 def auto_upgrade_config @auto_upgrade_config end |
#computed_release_channel ⇒ String
Output only. The computed release channel used for the Rollout Sequence.
Corresponds to the JSON property computedReleaseChannel
5947 5948 5949 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5947 def computed_release_channel @computed_release_channel end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was created.
Corresponds to the JSON property createTime
5952 5953 5954 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5952 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout Sequence was deleted.
Corresponds to the JSON property deleteTime
5957 5958 5959 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5957 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout Sequence.
Corresponds to the JSON property displayName
5962 5963 5964 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5962 def display_name @display_name end |
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property effectiveAutoUpgradeConfig
5967 5968 5969 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5967 def effective_auto_upgrade_config @effective_auto_upgrade_config end |
#etag ⇒ String
Output only. etag of the Rollout Sequence Ex. abc1234
Corresponds to the JSON property etag
5972 5973 5974 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5972 def etag @etag end |
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
Corresponds to the JSON property ignoredClustersSelector
5977 5978 5979 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5977 def ignored_clusters_selector @ignored_clusters_selector end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout Sequence.
Corresponds to the JSON property labels
5982 5983 5984 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5982 def labels @labels end |
#last_qualified_control_plane_version ⇒ String
Output only. The last qualified control plane version.
Corresponds to the JSON property lastQualifiedControlPlaneVersion
5987 5988 5989 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5987 def last_qualified_control_plane_version @last_qualified_control_plane_version end |
#last_qualified_node_version ⇒ String
Output only. The last qualified node version.
Corresponds to the JSON property lastQualifiedNodeVersion
5992 5993 5994 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5992 def last_qualified_node_version @last_qualified_node_version end |
#name ⇒ String
Identifier. Name of the rollout sequence in the format of: projects/
PROJECT_ID/locations/global/rolloutSequences/NAME
Corresponds to the JSON property name
5998 5999 6000 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5998 def name @name end |
#operational_state ⇒ Google::Apis::GkehubV1::OperationalState
Operational state of the Rollout Sequence.
Corresponds to the JSON property operationalState
6003 6004 6005 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6003 def operational_state @operational_state end |
#stages ⇒ Array<Google::Apis::GkehubV1::Stage>
Required. Ordered list of stages that constitutes this Rollout.
Corresponds to the JSON property stages
6008 6009 6010 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6008 def stages @stages end |
#target_control_plane_version ⇒ String
Output only. The target control plane version of the Rollout Sequence.
Corresponds to the JSON property targetControlPlaneVersion
6013 6014 6015 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6013 def target_control_plane_version @target_control_plane_version end |
#target_node_version ⇒ String
Output only. The target node version of the Rollout Sequence.
Corresponds to the JSON property targetNodeVersion
6018 6019 6020 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6018 def target_node_version @target_node_version end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout Sequence resources. If a Rollout Sequence resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6025 6026 6027 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6025 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was last updated.
Corresponds to the JSON property updateTime
6030 6031 6032 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6030 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6037 6038 6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6037 def update!(**args) @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config) @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config) @etag = args[:etag] if args.key?(:etag) @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector) @labels = args[:labels] if args.key?(:labels) @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version) @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version) @name = args[:name] if args.key?(:name) @operational_state = args[:operational_state] if args.key?(:operational_state) @stages = args[:stages] if args.key?(:stages) @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version) @target_node_version = args[:target_node_version] if args.key?(:target_node_version) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |