Class: Google::Apis::GkehubV1::RolloutStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Stage represents a single stage in the Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutStage

Returns a new instance of RolloutStage.



6108
6109
6110
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6075
6076
6077
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6075

def cluster_selector
  @cluster_selector
end

#end_timeString

Optional. Output only. The time at which the stage ended. Corresponds to the JSON property endTime

Returns:

  • (String)


6080
6081
6082
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6080

def end_time
  @end_time
end

#fleet_projectsArray<String>

Output only. The fleet projects from the sequence that was used to create this stage. Expected format: projects/project_number Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6086
6087
6088
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6086

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Duration to soak after this stage before starting the next stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6091
6092
6093
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6091

def soak_duration
  @soak_duration
end

#stage_numberFixnum

Output only. The stage number to which this status applies. Corresponds to the JSON property stageNumber

Returns:

  • (Fixnum)


6096
6097
6098
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6096

def stage_number
  @stage_number
end

#start_timeString

Optional. Output only. The time at which the stage started. Corresponds to the JSON property startTime

Returns:

  • (String)


6101
6102
6103
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6101

def start_time
  @start_time
end

#stateString

Output only. The state of the stage. Corresponds to the JSON property state

Returns:

  • (String)


6106
6107
6108
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6106

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6113
6114
6115
6116
6117
6118
6119
6120
6121
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6113

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @end_time = args[:end_time] if args.key?(:end_time)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
  @stage_number = args[:stage_number] if args.key?(:stage_number)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end