Class: Google::Apis::GkehubV1::RolloutStage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::RolloutStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Stage represents a single stage in the Rollout.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
-
#end_time ⇒ String
Optional.
-
#fleet_projects ⇒ Array<String>
Output only.
-
#soak_duration ⇒ String
Optional.
-
#stage_number ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutStage
constructor
A new instance of RolloutStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutStage
Returns a new instance of RolloutStage.
6107 6108 6109 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6074 6075 6076 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6074 def cluster_selector @cluster_selector end |
#end_time ⇒ String
Optional. Output only. The time at which the stage ended.
Corresponds to the JSON property endTime
6079 6080 6081 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6079 def end_time @end_time end |
#fleet_projects ⇒ Array<String>
Output only. The fleet projects from the sequence that was used to create this
stage. Expected format: projects/project_number
Corresponds to the JSON property fleetProjects
6085 6086 6087 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6085 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Duration to soak after this stage before starting the next stage.
Corresponds to the JSON property soakDuration
6090 6091 6092 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6090 def soak_duration @soak_duration end |
#stage_number ⇒ Fixnum
Output only. The stage number to which this status applies.
Corresponds to the JSON property stageNumber
6095 6096 6097 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6095 def stage_number @stage_number end |
#start_time ⇒ String
Optional. Output only. The time at which the stage started.
Corresponds to the JSON property startTime
6100 6101 6102 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6100 def start_time @start_time end |
#state ⇒ String
Output only. The state of the stage.
Corresponds to the JSON property state
6105 6106 6107 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6105 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6112 6113 6114 6115 6116 6117 6118 6119 6120 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6112 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @end_time = args[:end_time] if args.key?(:end_time) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) @stage_number = args[:stage_number] if args.key?(:stage_number) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |