Class: Google::Apis::GkehubV1::Scope
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Scope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Scope represents a Scope in a Fleet.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The resource name for the scope
projects/project/locations/location/ scopes/scope`Corresponds to the JSON propertyname`. -
#namespace_labels ⇒ Hash<String,String>
Optional.
-
#state ⇒ Google::Apis::GkehubV1::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scope
constructor
A new instance of Scope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scope
Returns a new instance of Scope.
6215 6216 6217 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the scope was created.
Corresponds to the JSON property createTime
6171 6172 6173 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6171 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the scope was deleted.
Corresponds to the JSON property deleteTime
6176 6177 6178 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6176 def delete_time @delete_time end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Scope.
Corresponds to the JSON property labels
6181 6182 6183 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6181 def labels @labels end |
#name ⇒ String
The resource name for the scope projects/project/locations/location/
scopes/scope`
Corresponds to the JSON propertyname`
6187 6188 6189 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6187 def name @name end |
#namespace_labels ⇒ Hash<String,String>
Optional. Scope-level cluster namespace labels. For the member clusters bound
to the Scope, these labels are applied to each namespace under the Scope.
Scope-level labels take precedence over Namespace-level labels (
namespace_labels in the Fleet Namespace resource) if they share a key. Keys
and values must be Kubernetes-conformant.
Corresponds to the JSON property namespaceLabels
6196 6197 6198 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6196 def namespace_labels @namespace_labels end |
#state ⇒ Google::Apis::GkehubV1::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
Corresponds to the JSON property state
6201 6202 6203 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6201 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all scope resources. If a scope resource is deleted and another resource with
the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6208 6209 6210 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6208 def uid @uid end |
#update_time ⇒ String
Output only. When the scope was last updated.
Corresponds to the JSON property updateTime
6213 6214 6215 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6213 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6220 6221 6222 6223 6224 6225 6226 6227 6228 6229 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6220 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |