Class: Google::Apis::GkehubV1::Scope
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Scope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Scope represents a Scope in a Fleet.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The resource name for the scope
projects/project/locations/location/ scopes/scope`Corresponds to the JSON propertyname`. -
#namespace_labels ⇒ Hash<String,String>
Optional.
-
#state ⇒ Google::Apis::GkehubV1::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scope
constructor
A new instance of Scope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scope
Returns a new instance of Scope.
5558 5559 5560 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the scope was created.
Corresponds to the JSON property createTime
5514 5515 5516 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5514 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the scope was deleted.
Corresponds to the JSON property deleteTime
5519 5520 5521 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5519 def delete_time @delete_time end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Scope.
Corresponds to the JSON property labels
5524 5525 5526 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5524 def labels @labels end |
#name ⇒ String
The resource name for the scope projects/project/locations/location/
scopes/scope`
Corresponds to the JSON propertyname`
5530 5531 5532 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5530 def name @name end |
#namespace_labels ⇒ Hash<String,String>
Optional. Scope-level cluster namespace labels. For the member clusters bound
to the Scope, these labels are applied to each namespace under the Scope.
Scope-level labels take precedence over Namespace-level labels (
namespace_labels in the Fleet Namespace resource) if they share a key. Keys
and values must be Kubernetes-conformant.
Corresponds to the JSON property namespaceLabels
5539 5540 5541 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5539 def namespace_labels @namespace_labels end |
#state ⇒ Google::Apis::GkehubV1::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
Corresponds to the JSON property state
5544 5545 5546 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5544 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all scope resources. If a scope resource is deleted and another resource with
the same name is created, it gets a different uid.
Corresponds to the JSON property uid
5551 5552 5553 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5551 def uid @uid end |
#update_time ⇒ String
Output only. When the scope was last updated.
Corresponds to the JSON property updateTime
5556 5557 5558 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5556 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5563 5564 5565 5566 5567 5568 5569 5570 5571 5572 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5563 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |