Class: Google::Apis::GkehubV1::ServiceMeshMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ServiceMeshMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Service Mesh: Spec for a single Membership for the servicemesh feature
Instance Attribute Summary collapse
-
#config_api ⇒ String
Optional.
-
#control_plane ⇒ String
Deprecated: use
managementinstead Enables automatic control plane management. -
#management ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshMembershipSpec
constructor
A new instance of ServiceMeshMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshMembershipSpec
Returns a new instance of ServiceMeshMembershipSpec.
6426 6427 6428 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_api ⇒ String
Optional. Specifies the API that will be used for configuring the mesh
workloads.
Corresponds to the JSON property configApi
6413 6414 6415 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6413 def config_api @config_api end |
#control_plane ⇒ String
Deprecated: use management instead Enables automatic control plane
management.
Corresponds to the JSON property controlPlane
6419 6420 6421 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6419 def control_plane @control_plane end |
#management ⇒ String
Optional. Enables automatic Service Mesh management.
Corresponds to the JSON property management
6424 6425 6426 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6424 def management @management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6431 6432 6433 6434 6435 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6431 def update!(**args) @config_api = args[:config_api] if args.key?(:config_api) @control_plane = args[:control_plane] if args.key?(:control_plane) @management = args[:management] if args.key?(:management) end |