Class: Google::Apis::GkehubV1::ServiceMeshMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshMembershipSpec

Returns a new instance of ServiceMeshMembershipSpec.



5769
5770
5771
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


5756
5757
5758
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5756

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


5762
5763
5764
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5762

def control_plane
  @control_plane
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


5767
5768
5769
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5767

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5774
5775
5776
5777
5778
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5774

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @management = args[:management] if args.key?(:management)
end