Class: Google::Apis::GkehubV1::ServiceMeshMembershipSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::ServiceMeshMembershipSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Service Mesh: Spec for a single Membership for the servicemesh feature
Instance Attribute Summary collapse
-
#config_api ⇒ String
Optional.
-
#control_plane ⇒ String
Deprecated: use
managementinstead Enables automatic control plane management. -
#management ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshMembershipSpec
constructor
A new instance of ServiceMeshMembershipSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshMembershipSpec
Returns a new instance of ServiceMeshMembershipSpec.
5769 5770 5771 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_api ⇒ String
Optional. Specifies the API that will be used for configuring the mesh
workloads.
Corresponds to the JSON property configApi
5756 5757 5758 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5756 def config_api @config_api end |
#control_plane ⇒ String
Deprecated: use management instead Enables automatic control plane
management.
Corresponds to the JSON property controlPlane
5762 5763 5764 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5762 def control_plane @control_plane end |
#management ⇒ String
Optional. Enables automatic Service Mesh management.
Corresponds to the JSON property management
5767 5768 5769 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5767 def management @management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5774 5775 5776 5777 5778 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 5774 def update!(**args) @config_api = args[:config_api] if args.key?(:config_api) @control_plane = args[:control_plane] if args.key?(:control_plane) @management = args[:management] if args.key?(:management) end |