Class: Google::Apis::GkehubV1::Stage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::Stage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Rollout stage.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
-
#fleet_projects ⇒ Array<String>
Required.
-
#soak_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stage
constructor
A new instance of Stage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stage
Returns a new instance of Stage.
6595 6596 6597 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6582 6583 6584 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6582 def cluster_selector @cluster_selector end |
#fleet_projects ⇒ Array<String>
Required. List of Fleet projects to select the clusters from. Expected format:
projects/project
Corresponds to the JSON property fleetProjects
6588 6589 6590 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6588 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Soak time after upgrading all the clusters in the stage.
Corresponds to the JSON property soakDuration
6593 6594 6595 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6593 def soak_duration @soak_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6600 6601 6602 6603 6604 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6600 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) end |