Class: Google::Apis::GkehubV1::Stage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Rollout stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stage

Returns a new instance of Stage.



6593
6594
6595
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6580
6581
6582
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6580

def cluster_selector
  @cluster_selector
end

#fleet_projectsArray<String>

Required. List of Fleet projects to select the clusters from. Expected format: projects/project Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6586
6587
6588
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6586

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Soak time after upgrading all the clusters in the stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6591
6592
6593
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6591

def soak_duration
  @soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6598
6599
6600
6601
6602
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6598

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
end