Class: Google::Apis::GkehubV1::Stage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Rollout stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stage

Returns a new instance of Stage.



6568
6569
6570
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6555
6556
6557
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6555

def cluster_selector
  @cluster_selector
end

#fleet_projectsArray<String>

Required. List of Fleet projects to select the clusters from. Expected format: projects/project Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6561
6562
6563
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6561

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Soak time after upgrading all the clusters in the stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6566
6567
6568
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6566

def soak_duration
  @soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6573
6574
6575
6576
6577
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6573

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
end