Class: Google::Apis::GkehubV1::UpgradeRolloutSequenceRequest
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::UpgradeRolloutSequenceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
Request message for upgrading a rollout sequence.
Instance Attribute Summary collapse
-
#force ⇒ Boolean
(also: #force?)
Optional.
-
#upgrade_type ⇒ String
Required.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeRolloutSequenceRequest
constructor
A new instance of UpgradeRolloutSequenceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeRolloutSequenceRequest
Returns a new instance of UpgradeRolloutSequenceRequest.
6729 6730 6731 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force ⇒ Boolean Also known as: force?
Optional. If set to true, any rollout already running on the first stage of
the sequence will be cancelled to allow for the creation of the new rollout.
Corresponds to the JSON property force
6706 6707 6708 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6706 def force @force end |
#upgrade_type ⇒ String
Required. The type of upgrade.
Corresponds to the JSON property upgradeType
6712 6713 6714 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6712 def upgrade_type @upgrade_type end |
#version ⇒ String
Required. GKE version to upgrade to. A valid GKE version available on the
release channel used by the sequence. Patch versions from less conservative
channels are allowed if their minor version is already available in the
sequence's channel. This is similar to single-cluster upgrade rules, see https:
//cloud.google.com/kubernetes-engine/docs/how-to/upgrading-a-cluster#supported-
versions Example: With the following versions available on the RAPID and
REGULAR channels: * REGULAR: 1.35.3-gke.123000 * RAPID: 1.36.4-gke.321000, 1.
35.6-gke.045000 Valid versions are 1.35.3-gke.123, 1.35.6-gke.045000 Aliases
like latest are supported. For more information on valid upgrade versions
and specifying cluster versions, see: https://cloud.google.com/kubernetes-
engine/versioning#specifying_cluster_version
Corresponds to the JSON property version
6727 6728 6729 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6727 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6734 6735 6736 6737 6738 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6734 def update!(**args) @force = args[:force] if args.key?(:force) @upgrade_type = args[:upgrade_type] if args.key?(:upgrade_type) @version = args[:version] if args.key?(:version) end |