Class: Google::Apis::GkehubV1::UpgradeRolloutSequenceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

Request message for upgrading a rollout sequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeRolloutSequenceRequest

Returns a new instance of UpgradeRolloutSequenceRequest.



6702
6703
6704
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If set to true, any rollout already running on the first stage of the sequence will be cancelled to allow for the creation of the new rollout. Corresponds to the JSON property force

Returns:

  • (Boolean)


6679
6680
6681
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6679

def force
  @force
end

#upgrade_typeString

Required. The type of upgrade. Corresponds to the JSON property upgradeType

Returns:

  • (String)


6685
6686
6687
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6685

def upgrade_type
  @upgrade_type
end

#versionString

Required. GKE version to upgrade to. A valid GKE version available on the release channel used by the sequence. Patch versions from less conservative channels are allowed if their minor version is already available in the sequence's channel. This is similar to single-cluster upgrade rules, see https: //cloud.google.com/kubernetes-engine/docs/how-to/upgrading-a-cluster#supported- versions Example: With the following versions available on the RAPID and REGULAR channels: * REGULAR: 1.35.3-gke.123000 * RAPID: 1.36.4-gke.321000, 1. 35.6-gke.045000 Valid versions are 1.35.3-gke.123, 1.35.6-gke.045000 Aliases like latest are supported. For more information on valid upgrade versions and specifying cluster versions, see: https://cloud.google.com/kubernetes- engine/versioning#specifying_cluster_version Corresponds to the JSON property version

Returns:

  • (String)


6700
6701
6702
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6700

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6707
6708
6709
6710
6711
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6707

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @upgrade_type = args[:upgrade_type] if args.key?(:upgrade_type)
  @version = args[:version] if args.key?(:version)
end