Class: Google::Apis::GkehubV1::WorkloadIdentityFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

WorkloadIdentity: Global feature state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityFeatureState

Returns a new instance of WorkloadIdentityFeatureState.



6077
6078
6079
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_state_detailsHash<String,Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail>

The state of the IAM namespaces for the fleet. Corresponds to the JSON property namespaceStateDetails



6054
6055
6056
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6054

def namespace_state_details
  @namespace_state_details
end

#namespace_statesHash<String,String>

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property namespaceStates

Returns:

  • (Hash<String,String>)


6060
6061
6062
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6060

def namespace_states
  @namespace_states
end

#scope_tenancy_workload_identity_poolString

The full name of the scope-tenancy pool for the fleet. Corresponds to the JSON property scopeTenancyWorkloadIdentityPool

Returns:

  • (String)


6065
6066
6067
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6065

def scope_tenancy_workload_identity_pool
  @scope_tenancy_workload_identity_pool
end

#workload_identity_poolString

The full name of the svc.id.goog pool for the fleet. Corresponds to the JSON property workloadIdentityPool

Returns:

  • (String)


6070
6071
6072
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6070

def workload_identity_pool
  @workload_identity_pool
end

#workload_identity_pool_state_detailsHash<String,Google::Apis::GkehubV1::WorkloadIdentityWorkloadIdentityPoolStateDetail>

The state of the Workload Identity Pools for the fleet. Corresponds to the JSON property workloadIdentityPoolStateDetails



6075
6076
6077
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6075

def workload_identity_pool_state_details
  @workload_identity_pool_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6082
6083
6084
6085
6086
6087
6088
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6082

def update!(**args)
  @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details)
  @namespace_states = args[:namespace_states] if args.key?(:namespace_states)
  @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool)
  @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool)
  @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details)
end