Class: Google::Apis::GkehubV1::WorkloadIdentityMembershipState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::WorkloadIdentityMembershipState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.
Instance Attribute Summary collapse
-
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new field.
-
#identity_provider_state_details ⇒ Hash<String,Google::Apis::GkehubV1::WorkloadIdentityIdentityProviderStateDetail>
The state of the Identity Providers corresponding to the membership.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityMembershipState
constructor
A new instance of WorkloadIdentityMembershipState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityMembershipState
Returns a new instance of WorkloadIdentityMembershipState.
6132 6133 6134 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Deprecated, this field will be erased after code is changed to use the new
field.
Corresponds to the JSON property description
6125 6126 6127 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6125 def description @description end |
#identity_provider_state_details ⇒ Hash<String,Google::Apis::GkehubV1::WorkloadIdentityIdentityProviderStateDetail>
The state of the Identity Providers corresponding to the membership.
Corresponds to the JSON property identityProviderStateDetails
6130 6131 6132 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6130 def identity_provider_state_details @identity_provider_state_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6137 6138 6139 6140 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6137 def update!(**args) @description = args[:description] if args.key?(:description) @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details) end |