Class: Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
6157 6158 6159 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
6150 6151 6152 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6150 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
6155 6156 6157 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6155 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6162 6163 6164 6165 |
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6162 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |