Class: Google::Apis::GkehubV1::WorkloadIdentityWorkloadIdentityPoolStateDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1/classes.rb,
lib/google/apis/gkehub_v1/representations.rb,
lib/google/apis/gkehub_v1/representations.rb

Overview

WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail

Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.



6183
6184
6185
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The state of the Workload Identity Pool. Corresponds to the JSON property code

Returns:

  • (String)


6176
6177
6178
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6176

def code
  @code
end

#descriptionString

A human-readable description of the current state or returned error. Corresponds to the JSON property description

Returns:

  • (String)


6181
6182
6183
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6181

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6188
6189
6190
6191
# File 'lib/google/apis/gkehub_v1/classes.rb', line 6188

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
end